@@ -2,8 +2,7 @@
 #
 # Project    : ipv6calc
 # File       : autogen-all-variants.sh
-# Version    : $Id: 7d33a8c898f4320bac72e940eeb50ab9a2927c2c $
-# Copyright  : 2011-2021 by Peter Bieringer <pb (at) bieringer.de>
+# Copyright  : 2011-2023 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Information: run autogen.sh with all supported variants
 #
@@ -44,7 +43,7 @@ autogen_variants_list() {
 		cat <<END | grep -v ^#
 NONE#
 BUNDLED#--enable-bundled-md5 --enable-bundled-getopt
-OPENSSL#--enable-openssl-md5
+OPENSSL#--enable-openssl-md5 --no-static-build
 OPENSSL#--enable-openssl-evp-md5
 IP2LOCATION#-i
 IP2LOCATION#-i --ip2location-dyn
