@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper.h
- * Version    : $Id: 7dc27180e82742324f3c536dbabe3c1a67a3f350 $
+ * Version    : $Id: 0dbed86cf1d322d0611f438a5505609cefb19624 $
  * Copyright  : 2013-2021 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -241,7 +241,7 @@ typedef struct
 	char     continent_code[IPV6CALC_DB_SIZE_CONTINENT_CODE];
 	char     continent_long[IPV6CALC_DB_SIZE_CONTINENT_LONG];
 	char     stateprov[IPV6CALC_DB_SIZE_STATEPROV];
-	char     district[IPV6CALC_DB_SIZE_CITY];
+	char     district[IPV6CALC_DB_SIZE_DISTRICT];
 	char     city[IPV6CALC_DB_SIZE_CITY];
 	char     zipcode[IPV6CALC_DB_SIZE_ZIPCODE];
 	char     weatherstationcode[IPV6CALC_DB_SIZE_WEATHERSTATIONCODE];
