@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_BuiltIn.c
- * Version    : $Id: c9d6dc476e5101f49325c07446b74fbcecf7dce8 $
- * Copyright  : 2013-2017 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: dfd3157323edf7dd4bdaa165125f6b012f569f9b $
+ * Copyright  : 2013-2021 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  ipv6calc BuiltIn database wrapper
@@ -47,6 +47,7 @@ static int builtin_ieee       = 0;
 #ifdef SUPPORT_DB_IEEE
 #include "../ieee-iab/dbieee_iab.h"
 #include "../ieee-oui/dbieee_oui.h"
+#include "../ieee-oui28/dbieee_oui28.h"
 #include "../ieee-oui36/dbieee_oui36.h"
 #endif
 
@@ -64,7 +65,7 @@ static uint32_t builtin_db_usage_map[BUILTIN_DB_MAX_BLOCKS_32];
 							exit(1); \
 						};
 
-char builtin_db_usage_string[NI_MAXHOST] = "";
+char builtin_db_usage_string[IPV6CALC_STRING_MAX] = "";
 
 
 /*
@@ -159,9 +160,7 @@ void libipv6calc_db_wrapper_BuiltIn_wrapper_info(char* string, const size_t size
 void libipv6calc_db_wrapper_BuiltIn_wrapper_print_db_info(const int level_verbose, const char *prefix_string) {
 	const char *prefix = "\0";
 
-	if (level_verbose == 0) { }; // make compiler happy (avoid unused "...")
-
-	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Called");
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Called with verbose: %d", level_verbose);
 
 	if (prefix_string != NULL) {
 		prefix = prefix_string;
@@ -171,7 +170,7 @@ void libipv6calc_db_wrapper_BuiltIn_wrapper_print_db_info(const int level_verbos
 
 #ifdef SUPPORT_BUILTIN
 #if defined SUPPORT_DB_IPV4_REG || defined SUPPORT_DB_IPV6_REG
-	char tempstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
 #endif
 
 	fprintf(stderr, "%sBuiltIn: info of available databases\n", prefix);
@@ -204,7 +203,7 @@ void libipv6calc_db_wrapper_BuiltIn_wrapper_print_db_info(const int level_verbos
 
 #ifdef SUPPORT_DB_IEEE
 	if (wrapper_features_by_source[IPV6CALC_DB_SOURCE_BUILTIN] & IPV6CALC_DB_IEEE_TO_INFO) {
-		fprintf(stderr, "%sBuiltIn: %-5s: %s %s %s\n", prefix, "IEEE", libieee_iab_status, libieee_oui_status, libieee_oui36_status);
+		fprintf(stderr, "%sBuiltIn: %-5s: %s %s %s %s\n", prefix, "IEEE", libieee_iab_status, libieee_oui_status, libieee_oui28_status, libieee_oui36_status);
 	};
 #endif
 
@@ -222,8 +221,10 @@ void libipv6calc_db_wrapper_BuiltIn_wrapper_print_db_info(const int level_verbos
  */
 char *libipv6calc_db_wrapper_BuiltIn_wrapper_db_info_used(void) {
 	int type, i;
-	char tempstring[NI_MAXHOST];
-	char tempstring2[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
+#if defined SUPPORT_DB_IPV4_REG || defined SUPPORT_DB_IPV6_REG || defined SUPPORT_DB_IEEE || defined SUPPORT_DB_AS_REG || defined SUPPORT_DB_CC_REG
+	char tempstring2[IPV6CALC_STRING_MAX];
+#endif
 	char *info;
 
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Called");
@@ -260,6 +261,10 @@ char *libipv6calc_db_wrapper_BuiltIn_wrapper_db_info_used(void) {
 				snprintf(tempstring2, sizeof(tempstring2), "IEEE:%s", libieee_oui_status);
 				info = tempstring2;
 				break;
+			    case BUILTIN_DB_OUI28:
+				snprintf(tempstring2, sizeof(tempstring2), "IEEE:%s", libieee_oui28_status);
+				info = tempstring2;
+				break;
 			    case BUILTIN_DB_OUI36:
 				snprintf(tempstring2, sizeof(tempstring2), "IEEE:%s", libieee_oui36_status);
 				info = tempstring2;
@@ -496,6 +501,18 @@ int libipv6calc_db_wrapper_BuiltIn_ieee_vendor_string_by_macaddr(char *resultstr
 		};
 	};
 
+	/* run through OUI28 list */
+	for (i = 0; i < MAXENTRIES_ARRAY(libieee_oui28); i++) {
+		if (libieee_oui28[i].id == idval) {
+			/* major id match */
+			if (libieee_oui28[i].subid_begin <= subidval && libieee_oui28[i].subid_end >= subidval) {
+				snprintf(resultstring, resultstring_length, "%s", libieee_oui28[i].string_owner);
+				BUILTIN_DB_USAGE_MAP_TAG(BUILTIN_DB_OUI28);
+				return (0);
+			};
+		};
+	};
+
 	/* run through OUI list */
 	for (i = 0; i < MAXENTRIES_ARRAY(libieee_oui); i++) {
 		if (libieee_oui[i].id == idval) {
@@ -572,6 +589,18 @@ int libipv6calc_db_wrapper_BuiltIn_ieee_vendor_string_short_by_macaddr(char *res
 		};
 	};
 
+	/* run through OUI28 list */
+	for (i = 0; i < MAXENTRIES_ARRAY(libieee_oui28); i++) {
+		if (libieee_oui28[i].id == idval) {
+			/* major id match */
+			if (libieee_oui28[i].subid_begin <= subidval && libieee_oui28[i].subid_end >= subidval) {
+				snprintf(resultstring, resultstring_length, "%s", libieee_oui28[i].shortstring_owner);
+				BUILTIN_DB_USAGE_MAP_TAG(BUILTIN_DB_OUI28);
+				return (0);
+			};
+		};
+	};
+
 	/* run through OUI list */
 	for (i = 0; i < MAXENTRIES_ARRAY(libieee_oui); i++) {
 		if (libieee_oui[i].id == idval) {
@@ -683,7 +712,7 @@ int libipv6calc_db_wrapper_BuiltIn_registry_num_by_ipv4addr(const ipv6calc_ipv4a
 
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Given IPv4 address: %08x", (unsigned int) ipv4);
 
-	int result = IPV4_ADDR_REGISTRY_UNKNOWN;
+	int result = REGISTRY_UNKNOWN;
 
 #ifdef SUPPORT_DB_IPV4_REG
 	int match = -1;
@@ -708,7 +737,7 @@ int libipv6calc_db_wrapper_BuiltIn_registry_num_by_ipv4addr(const ipv6calc_ipv4a
 		BUILTIN_DB_USAGE_MAP_TAG(BUILTIN_DB_IPV4_REGISTRY);
 	};
 
-	if (result == IPV4_ADDR_REGISTRY_UNKNOWN) {
+	if (result == REGISTRY_UNKNOWN) {
 		// IANA fallback
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Nothing found in dbipv4addr_assignment, fallback now to dbipv4addr_assignment_iana");
 
@@ -859,10 +888,10 @@ int libipv6calc_db_wrapper_BuiltIn_registry_num_by_ipv6addr(const ipv6calc_ipv6a
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Given ipv6 prefix: %08x%08x", (unsigned int) ipv6_00_31, (unsigned int) ipv6_32_63);
 
 	if ((ipv6addrp->typeinfo & IPV6_NEW_ADDR_6BONE) != 0) {
-		return(IPV6_ADDR_REGISTRY_6BONE);
+		return(REGISTRY_6BONE);
 	};
 
-	int result = IPV6_ADDR_REGISTRY_UNKNOWN;
+	int result = REGISTRY_UNKNOWN;
 
 #ifdef SUPPORT_DB_IPV6_REG
 	int match = -1;
