@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_DBIP2.c
- * Version    : $Id: 0374cfb1ce43b164edceb1589fc54204b56cae50 $
+ * Version    : $Id: ab735debd350836439cc62796cc3676cbc360d7e $
  * Copyright  : 2019-2021 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -340,7 +340,7 @@ int libipv6calc_db_wrapper_DBIP2_wrapper_cleanup(void) {
 void libipv6calc_db_wrapper_DBIP2_wrapper_info(char* string, const size_t size) {
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_DBIP2, "Called");
 
-	snprintf(string, size, "DBIP2 available databases: Country4=%d Country6=%d ASN4=%d ASN6=%d City4=%d City6=%d", \
+	snprintf(string, size, "DBIP2 database support: Country4=%d Country6=%d ASN4=%d ASN6=%d City4=%d City6=%d", \
 		(wrapper_features & IPV6CALC_DB_IPV4_TO_CC) ? 1 : 0, \
 		(wrapper_features & IPV6CALC_DB_IPV6_TO_CC) ? 1 : 0, \
 		(wrapper_features & IPV6CALC_DB_IPV4_TO_AS) ? 1 : 0, \
