@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_External.c
- * Version    : $Id: 87ab89652d073434349d260d650bd0faaba727d6 $
- * Copyright  : 2013-2019 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 1d6ec7f1550d6741dd8ff719d24a8ae362230692 $
+ * Copyright  : 2013-2022 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  ipv6calc External (superseeding BuiltIn) database wrapper
@@ -20,6 +20,7 @@
 
 #include "libipv6calcdebug.h"
 #include "libipv6calc.h"
+#include "librfc3056.h"
 
 #include "libipv6calc_db_wrapper.h"
 
@@ -30,7 +31,7 @@
 
 #include "libipv6calc_db_wrapper_External.h"
 
-char external_db_dir[NI_MAXHOST] = EXTERNAL_DB;
+char external_db_dir[PATH_MAX] = EXTERNAL_DB;
 
 static const char* wrapper_external_info = "External";
 
@@ -47,7 +48,7 @@ static uint32_t external_db_usage_map[EXTERNAL_DB_MAX_BLOCKS_32];
 							exit(1); \
 						};
 
-char external_db_usage_string[NI_MAXHOST] = "";
+char external_db_usage_string[IPV6CALC_STRING_MAX] = "";
 
 // local cache
 #define IPV6CALC_DBD_SUBDB_MAX 3
@@ -171,19 +172,23 @@ static int libipv6calc_db_wrapper_External_close(DB *dbp) {
  */
 int libipv6calc_db_wrapper_External_wrapper_cleanup(void) {
 	int i, j;
+	int hit;
 
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_External, "Called");
 
-#ifdef SUPPORT_EXTERNAL
 	for (i = 0; i < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_External_db_file_desc); i++) {
-		if (db_ptr_cache[i] != NULL) {
-			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "Close External: type=%d desc='%s'", libipv6calc_db_wrapper_External_db_file_desc[i].number, libipv6calc_db_wrapper_External_db_file_desc[i].description);
-			for (j = 0; j < IPV6CALC_DBD_SUBDB_MAX; j++) {
+		hit = 0;
+		for (j = 0; j < IPV6CALC_DBD_SUBDB_MAX; j++) {
+			if (db_ptr_cache[i][j] != NULL) {
+				if (hit == 0) {
+					// display debug message only once per i (type)
+					DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "Close External: type=%d desc='%s'", libipv6calc_db_wrapper_External_db_file_desc[i].number, libipv6calc_db_wrapper_External_db_file_desc[i].description);
+					hit = 1;
+				};
 				libipv6calc_db_wrapper_External_close(db_ptr_cache[i][j]);
 			};
 		};
 	};
-#endif
 
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_External, "Finished");
 	return 0;
@@ -199,16 +204,12 @@ int libipv6calc_db_wrapper_External_wrapper_cleanup(void) {
 void libipv6calc_db_wrapper_External_wrapper_info(char* string, const size_t size) {
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_External, "Called");
 
-#ifdef SUPPORT_EXTERNAL
 	snprintf(string, size, "External available databases: Country4=%d Country6=%d IPV4_REG=%d IPV6_REG=%d", \
 		(wrapper_features & IPV6CALC_DB_IPV4_TO_CC) ? 1 : 0, \
 		(wrapper_features & IPV6CALC_DB_IPV6_TO_CC) ? 1 : 0, \
 		(wrapper_features & IPV6CALC_DB_IPV4_TO_REGISTRY) ? 1 : 0, \
 		(wrapper_features & IPV6CALC_DB_IPV6_TO_REGISTRY) ? 1 : 0 \
 	);
-#else
-	snprintf(string, size, "No External database support built-in");
-#endif
 
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_External, "Finished");
 	return;
@@ -232,29 +233,25 @@ void libipv6calc_db_wrapper_External_wrapper_print_db_info(const int level_verbo
 
 	IPV6CALC_DB_FEATURE_INFO(prefix, IPV6CALC_DB_SOURCE_EXTERNAL)
 
-#ifdef SUPPORT_EXTERNAL
-	printf("%sExternal: info of available databases in directory: %s\n", prefix, external_db_dir);
+	fprintf(stderr, "%sExternal: info of available databases in directory: %s\n", prefix, external_db_dir);
 
 	for (i = 0; i < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_External_db_file_desc); i++) {
 		type = libipv6calc_db_wrapper_External_db_file_desc[i].number;
 
 		if (libipv6calc_db_wrapper_External_db_avail(type)) {
-			printf("%sExternal: %-20s: %-40s (%s)\n", prefix, libipv6calc_db_wrapper_External_db_file_desc[i].description, libipv6calc_db_wrapper_External_db_file_desc[i].filename, libipv6calc_db_wrapper_External_database_info(type));
+			fprintf(stderr, "%sExternal: %-20s: %-40s (%s)\n", prefix, libipv6calc_db_wrapper_External_db_file_desc[i].description, libipv6calc_db_wrapper_External_db_file_desc[i].filename, libipv6calc_db_wrapper_External_database_info(type));
 			count++;
 		} else {
 			if (level_verbose == LEVEL_VERBOSE2) {
-				printf("%sExternal: %-20s: %-40s (%s)\n", prefix, libipv6calc_db_wrapper_External_db_file_desc[i].description, libipv6calc_db_wrapper_External_dbfilename(type), strerror(errno));
+				fprintf(stderr, "%sExternal: %-20s: %-40s (%s)\n", prefix, libipv6calc_db_wrapper_External_db_file_desc[i].description, libipv6calc_db_wrapper_External_dbfilename(type), strerror(errno));
 			};
 			continue;
 		};
 	};
 
 	if (count == 0) {
-		printf("%sExternal: NO available databases found in directory: %s\n", prefix, external_db_dir);
+		fprintf(stderr, "%sExternal: NO available databases found in directory: %s\n", prefix, external_db_dir);
 	};
-#else // SUPPORT_EXTERNAL
-	snprintf(string, size, "%sNo External support built-in", prefix);
-#endif // SUPPORT_EXTERNAL
 
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_External, "Finished");
 	return;
@@ -266,7 +263,7 @@ void libipv6calc_db_wrapper_External_wrapper_print_db_info(const int level_verbo
  */
 char *libipv6calc_db_wrapper_External_wrapper_db_info_used(void) {
 	int type, i;
-	char tempstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
 	char *info;
 
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_External, "Called");
@@ -307,9 +304,6 @@ char *libipv6calc_db_wrapper_External_wrapper_db_info_used(void) {
 };
 
 
-
-#ifdef SUPPORT_EXTERNAL
-
 /*******************************
  * Wrapper extension functions for External
  *******************************/
@@ -318,7 +312,7 @@ char *libipv6calc_db_wrapper_External_wrapper_db_info_used(void) {
  * wrapper extension: External_dbfilename
  */
 static char *libipv6calc_db_wrapper_External_dbfilename(unsigned int type) {
-	static char tempstring[NI_MAXHOST];
+	static char tempstring[IPV6CALC_STRING_MAX];
 	int  entry = -1, i;
 
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "Called: %s type=%d", wrapper_external_info, type);
@@ -549,9 +543,9 @@ END_libipv6calc_db_wrapper:
  * wrapper: External_database_info
  */
 char *libipv6calc_db_wrapper_External_database_info(const unsigned int type) {
-	static char resultstring[NI_MAXHOST] = "";
-	char datastring[NI_MAXHOST];
-	char tempstring[NI_MAXHOST];
+	static char resultstring[IPV6CALC_STRING_MAX] = ""; // has to be static because pointer is returned
+	char datastring[IPV6CALC_STRING_MAX];
+	char tempstring[IPV6CALC_STRING_MAX];
 	int ret, i, entry = -1;
 	DB *dbp;
 
@@ -678,142 +672,6 @@ time_t libipv6calc_db_wrapper_External_db_unixtime_by_feature(uint32_t feature)
 };
 
 
-/* registry by address */
-int libipv6calc_db_wrapper_External_wrapper_registry_by_addr(const char *addr, const int proto) {
-	int result = REGISTRY_UNKNOWN;
-
-	int i;
-	DB *dbp;
-
-	static char resultstring[NI_MAXHOST];
-
-	char *data_ptr = "";
-
-	int External_type = 0;
-
-	ipv6calc_ipv4addr ipv4addr;
-	ipv6calc_ipv6addr ipv6addr;
-
-	uint32_t ipv4 = 0, ipv6_00_31 = 0, ipv6_32_63 = 0;
-
-	long int recno_max;
-
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "Called with addr=%s proto=%d", addr, proto);
-
-	if (proto == 4) {
-		External_type = EXTERNAL_DB_IPV4_REGISTRY;
-
-		if ((wrapper_features_by_source[IPV6CALC_DB_SOURCE_EXTERNAL] & IPV6CALC_DB_IPV4_TO_REGISTRY) == 0) {
-			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_External, "No external database supporting IPv4 registry available");
-			goto END_libipv6calc_db_wrapper;
-		};
-		// convert char to structure
-		result = addr_to_ipv4addrstruct(addr, resultstring, sizeof(resultstring), &ipv4addr);
-	} else if (proto == 6) {
-		External_type = EXTERNAL_DB_IPV6_REGISTRY;
-
-		if ((wrapper_features_by_source[IPV6CALC_DB_SOURCE_EXTERNAL] & IPV6CALC_DB_IPV6_TO_REGISTRY) == 0) {
-			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_External, "No external database supporting IPv6 registry available");
-			goto END_libipv6calc_db_wrapper;
-		};
-
-		// convert char to structure
-		result = addr_to_ipv6addrstruct(addr, resultstring, sizeof(resultstring), &ipv6addr);
-	} else {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "Unsupported proto: %d", proto);
-		goto END_libipv6calc_db_wrapper;
-	};
-
-	if (result != 0) {
-		ERRORPRINT_WA("error converting address string for proto %d: %s", proto, addr);
-		goto END_libipv6calc_db_wrapper;
-	};
-
-	dbp = libipv6calc_db_wrapper_External_open_type(External_type, &recno_max);
-
-	if (dbp == NULL) {
-		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_External, "Error opening External by type");
-		goto END_libipv6calc_db_wrapper;
-	};
-
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "database opened type=%d recno_max=%ld", External_type, recno_max);
-
-	if (proto == 4) {
-		ipv4 = ipv4addr_getdword(&ipv4addr);
-	} else if (proto == 6) {
-		ipv6_00_31 = ipv6addr_getdword(&ipv6addr, 0);
-		ipv6_32_63 = ipv6addr_getdword(&ipv6addr, 1);
-	};
-
-	result = libipv6calc_db_wrapper_get_entry_generic(
-		(void *) dbp,						// pointer to database
-		IPV6CALC_DB_LOOKUP_DATA_PTR_TYPE_BDB,			// type of data_ptr
-		IPV6CALC_DB_LOOKUP_DATA_KEY_TYPE_FIRST_LAST,		// key type
-		(proto == 4) ? IPV6CALC_DB_LOOKUP_DATA_DBD_FORMAT_SEMICOLON_SEP_DEC_32x2 : IPV6CALC_DB_LOOKUP_DATA_DBD_FORMAT_SEMICOLON_SEP_DEC_32x4,   // key format
-		(proto == 4) ? 32 : 64,					// key length
-		IPV6CALC_DB_LOOKUP_DATA_SEARCH_TYPE_BINARY,		// search type
-		recno_max,						// number of rows
-		(proto == 4) ? ipv4 : ipv6_00_31,			// lookup key MSB
-		(proto == 4) ? 0    : ipv6_32_63,			// lookup key LSB
-		resultstring,						// data ptr
-		NULL							// function pointer
-	);
-
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "resultstring=%s", resultstring);
-
-	char datastring[NI_MAXHOST];
-
-	char *token, *cptr, **ptrptr;
-	ptrptr = &cptr;
-
-	int token_count = 0;
-
-	snprintf(datastring, sizeof(datastring), "%s", data_ptr);
-
-	// split result string
-	token = strtok_r(resultstring, ";", ptrptr);
-	while (token != NULL) {
-		token_count++;
-
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "Database entry found %d: %s", token_count, token);
-
-		if (token_count == 1) {
-			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_registries); i++) {
-				if (strcmp(token, ipv6calc_registries[i].tokensimple) == 0) {
-					result = ipv6calc_registries[i].number;
-					break;
-				};
-			};
-		};
-
-		/* get next token */
-		token = strtok_r(NULL, ";", ptrptr);
-	};
-
-	if (token_count != 1) {
-		ERRORPRINT_WA("data has more entries than expected, corrupt database: %d", token_count);
-		goto END_libipv6calc_db_wrapper_close;
-	};
-
-	if (result == REGISTRY_UNKNOWN) {
-		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_External, "did not return a record for 'registry'");
-		goto END_libipv6calc_db_wrapper;
-	};
-
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "result registry=%d", result);
-
-	EXTERNAL_DB_USAGE_MAP_TAG(External_type);
-
-	goto END_libipv6calc_db_wrapper; // keep db open
-
-END_libipv6calc_db_wrapper_close:
-	libipv6calc_db_wrapper_External_close(dbp);
-
-END_libipv6calc_db_wrapper:
-	return(result);
-};
-
-
 /*
  * get registry number of an IPv4/IPv6 address
  *
@@ -823,8 +681,7 @@ END_libipv6calc_db_wrapper:
 int libipv6calc_db_wrapper_External_registry_num_by_addr(const ipv6calc_ipaddr *ipaddrp) {
 	DB *dbp, *dbp_iana;
 	long int recno_max;
-	static char resultstring[NI_MAXHOST];
-	char *data_ptr = "";
+	char resultstring[IPV6CALC_STRING_MAX];
 	int i, result;
 	int retval = REGISTRY_UNKNOWN;
 
@@ -925,27 +782,25 @@ int libipv6calc_db_wrapper_External_registry_num_by_addr(const ipv6calc_ipaddr *
 	goto END_libipv6calc_db_wrapper;
 
 END_libipv6calc_db_wrapper_match:
-
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "resultstring=%s", resultstring);
 
-	char datastring[NI_MAXHOST];
+	char datastring[IPV6CALC_STRING_MAX];
+	snprintf(datastring, sizeof(datastring), "%s", resultstring); // copy string for strtok
 
 	char *token, *cptr, **ptrptr;
 	ptrptr = &cptr;
 
 	int token_count = 0;
 
-	snprintf(datastring, sizeof(datastring), "%s", data_ptr);
-
 	// split result string
-	token = strtok_r(resultstring, ";", ptrptr);
+	token = strtok_r(datastring, ";", ptrptr);
 	while (token != NULL) {
 		token_count++;
 
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "Database entry found %d: %s", token_count, token);
 
 		if (token_count == 1) {
-			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_registries); i++) {
+			for (i = 0; i < ipv6calc_registries_entries; i++) {
 				if (strcmp(token, ipv6calc_registries[i].tokensimple) == 0) {
 					retval = ipv6calc_registries[i].number;
 					break;
@@ -958,8 +813,8 @@ END_libipv6calc_db_wrapper_match:
 	};
 
 	if (token_count != 1) {
-		ERRORPRINT_WA("data has more entries than expected, corrupt database: %d", token_count);
-		goto END_libipv6calc_db_wrapper_close;
+		ERRORPRINT_WA("data has more entries than expected, corrupt database: %d (resultstring='%s' prefix=%08x%08x)", token_count, resultstring, (unsigned int) ipaddrp->addr[0], (unsigned int) ipaddrp->addr[1]);
+		goto END_libipv6calc_db_wrapper;
 	};
 
 	if (retval == REGISTRY_UNKNOWN) {
@@ -971,11 +826,6 @@ END_libipv6calc_db_wrapper_match:
 
 	EXTERNAL_DB_USAGE_MAP_TAG(External_type);
 
-	goto END_libipv6calc_db_wrapper; // keep db open
-
-END_libipv6calc_db_wrapper_close:
-	libipv6calc_db_wrapper_External_close(dbp);
-
 END_libipv6calc_db_wrapper:
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "retval=%d", retval);
 	return(retval);
@@ -992,8 +842,7 @@ END_libipv6calc_db_wrapper:
 int libipv6calc_db_wrapper_External_country_code_by_addr(const ipv6calc_ipaddr *ipaddrp, char *country, const size_t country_len) {
 	DB *dbp;
 	long int recno_max;
-	static char resultstring[NI_MAXHOST];
-	char *data_ptr = "";
+	static char resultstring[IPV6CALC_STRING_MAX];
 	int result;
 	int retval = -1;
 
@@ -1056,17 +905,16 @@ int libipv6calc_db_wrapper_External_country_code_by_addr(const ipv6calc_ipaddr *
 
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "resultstring=%s", resultstring);
 
-	char datastring[NI_MAXHOST];
+	char datastring[IPV6CALC_STRING_MAX];
+	snprintf(datastring, sizeof(datastring), "%s", resultstring); // copy string for strtok
 
 	char *token, *cptr, **ptrptr;
 	ptrptr = &cptr;
 
 	int token_count = 0;
 
-	snprintf(datastring, sizeof(datastring), "%s", data_ptr);
-
 	// split result string
-	token = strtok_r(resultstring, ";", ptrptr);
+	token = strtok_r(datastring, ";", ptrptr);
 	while (token != NULL) {
 		token_count++;
 
@@ -1082,8 +930,8 @@ int libipv6calc_db_wrapper_External_country_code_by_addr(const ipv6calc_ipaddr *
 	};
 
 	if (token_count != 1) {
-		ERRORPRINT_WA("data has more entries than expected, corrupt database: %d", token_count);
-		goto END_libipv6calc_db_wrapper_close;
+		ERRORPRINT_WA("data has more entries than expected, corrupt database: %d (resultstring='%s' prefix=%08x%08x)", token_count, resultstring, (unsigned int) ipaddrp->addr[0], (unsigned int) ipaddrp->addr[1]);
+		goto END_libipv6calc_db_wrapper;
 	};
 
 	if (strlen(country) != 2) {
@@ -1097,11 +945,6 @@ int libipv6calc_db_wrapper_External_country_code_by_addr(const ipv6calc_ipaddr *
 
 	EXTERNAL_DB_USAGE_MAP_TAG(External_type);
 
-	goto END_libipv6calc_db_wrapper; // keep db open
-
-END_libipv6calc_db_wrapper_close:
-	libipv6calc_db_wrapper_External_close(dbp);
-
 END_libipv6calc_db_wrapper:
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "retval=%d", retval);
 	return(retval);
@@ -1119,8 +962,7 @@ END_libipv6calc_db_wrapper:
 int libipv6calc_db_wrapper_External_info_by_ipaddr(const ipv6calc_ipaddr *ipaddrp, char *string, const size_t string_len) {
 	DB *dbp;
 	long int recno_max;
-	static char resultstring[NI_MAXHOST];
-	char *data_ptr = "";
+	char resultstring[IPV6CALC_STRING_MAX];
 	int result;
 	int retval = -1;
 
@@ -1183,17 +1025,16 @@ int libipv6calc_db_wrapper_External_info_by_ipaddr(const ipv6calc_ipaddr *ipaddr
 
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "resultstring=%s", resultstring);
 
-	char datastring[NI_MAXHOST];
+	char datastring[IPV6CALC_STRING_MAX];
+	snprintf(datastring, sizeof(datastring), "%s", resultstring); // copy string for strtok
 
 	char *token, *cptr, **ptrptr;
 	ptrptr = &cptr;
 
 	int token_count = 0;
 
-	snprintf(datastring, sizeof(datastring), "%s", data_ptr);
-
 	// split result string
-	token = strtok_r(resultstring, ";", ptrptr);
+	token = strtok_r(datastring, ";", ptrptr);
 	while (token != NULL) {
 		token_count++;
 
@@ -1209,8 +1050,8 @@ int libipv6calc_db_wrapper_External_info_by_ipaddr(const ipv6calc_ipaddr *ipaddr
 	};
 
 	if (token_count != 1) {
-		ERRORPRINT_WA("data has more entries than expected, corrupt database: %d", token_count);
-		goto END_libipv6calc_db_wrapper_close;
+		ERRORPRINT_WA("data has more entries than expected, corrupt database: %d (resultstring='%s' prefix=%08x%08x)", token_count, resultstring, (unsigned int) ipaddrp->addr[0], (unsigned int) ipaddrp->addr[1]);
+		goto END_libipv6calc_db_wrapper;
 	};
 
 	if (strlen(string) == 0) {
@@ -1224,16 +1065,390 @@ int libipv6calc_db_wrapper_External_info_by_ipaddr(const ipv6calc_ipaddr *ipaddr
 
 	EXTERNAL_DB_USAGE_MAP_TAG(External_type);
 
-	goto END_libipv6calc_db_wrapper; // keep db open
-
-END_libipv6calc_db_wrapper_close:
-	libipv6calc_db_wrapper_External_close(dbp);
-
 END_libipv6calc_db_wrapper:
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "retval=%d", retval);
 	return(retval);
 };
 
 
-#endif //SUPPORT_EXTERNAL
+/*
+ * database dump
+ *
+ * in:  selector
+ * in:  filter ('External' database only supports CountryCode so far)
+ * in:  formatoptions
+ * out: 0=OK
+ */
+int libipv6calc_db_wrapper_External_dump(const int selector, const s_ipv6calc_filter_master *filter_master, const uint32_t outputtype, const uint32_t formatoptions, const char *name_ipset) {
+	DB *dbp;
+	long int recno_max, recno, count = 0;
+	char resultstring[IPV6CALC_STRING_MAX];
+	char tempstring[IPV6CALC_STRING_MAX];
+	char filterstring[IPV6CALC_STRING_MAX] = "";
+	char conversionstring[IPV6CALC_STRING_MAX] = "";
+	int result;
+	int retval = -1;
+	char protocol;
+	int i;
+
+	uint32_t value_first_00_31, value_last_00_31;
+        uint32_t value_first_32_63, value_last_32_63;
+
+	const s_ipv6calc_filter_db_cc *filter_db_cc;
+
+	int External_type, key_format;
+
+	char cc2[IPV6CALC_COUNTRYCODE_STRING_MAX];
+
+	int prefixlength;
+	uint32_t mask;
+	uint32_t delta;
+
+	ipv6calc_ipaddr ipaddr, ipaddr2;
+	ipv6calc_ipv6addr ipv6addr;
+	ipv6calc_ipv4addr ipv4addr;
+
+	int print_ipset = 0;
+
+	// general failsafe check
+	if ((formatoptions & FORMATOPTION_print_ipset) > 0) {
+		if (name_ipset == NULL) {
+			ERRORPRINT_NA("Format 'print-ipset <name>' selected but no name provided");
+			return (1);
+		};
+
+		if (strlen(name_ipset) == 0) {
+			ERRORPRINT_NA("Format 'print-ipset <name>' selected but name has zero length");
+			return (1);
+		};
+
+		// enable
+		print_ipset = 1;
+	};
+
+	// failsafe check per proto
+	switch (selector) {
+	    case IPV6CALC_PROTO_IPV4:
+		External_type = EXTERNAL_DB_IPV4_COUNTRYCODE;
+		protocol = '4';
+		key_format = IPV6CALC_DB_LOOKUP_DATA_DBD_FORMAT_SEMICOLON_SEP_HEX_32x2;
+
+		if (filter_master->filter_ipv4addr.active == 0) {
+			ERRORPRINT_NA("no IPv4 filter provided (-E ...)");
+			return (1);
+		};
+
+		if (filter_master->filter_ipv4addr.filter_db_cc.active == 0) {
+			ERRORPRINT_NA("no IPv4 Database CountryCode filter provided (-E ipv4.db.cc=<CountryCode>)");
+			return (1);
+		};
+
+		if (filter_master->filter_ipv4addr.filter_db_asn.active != 0) {
+			ERRORPRINT_NA("IPv4 ASN filter currently not supported for database dump");
+			return (1);
+		};
+
+		if (filter_master->filter_ipv4addr.filter_db_registry.active != 0) {
+			ERRORPRINT_NA("IPv4 Registry filter currently not supported for database dump");
+			return (1);
+		};
+
+		if (filter_master->filter_ipv4addr.filter_typeinfo.active != 0) {
+			ERRORPRINT_NA("IPv4 TypeInfo filter currently not supported for database dump");
+			return (1);
+		};
+
+		if (filter_master->filter_ipv4addr.filter_addr.active != 0) {
+			ERRORPRINT_NA("IPv4 Address filter currently not supported for database dump");
+			return (1);
+		};
+
+		filter_db_cc = &filter_master->filter_ipv4addr.filter_db_cc;
+
+		// check for supported outputtype
+		switch (outputtype) {
+			case FORMAT_ipv4addr:
+			case FORMAT_ipv6to4:
+			case FORMAT_undefined:
+				// supported
+				break;
+
+			default:
+				ERRORPRINT_WA("Outputtype for IPv4 Address is not supported: 0x%08x", outputtype);
+				return (1);
+				break;
+		};
+
+		// check for supported outputtype
+		switch (outputtype) {
+			case FORMAT_ipv6to4:
+				snprintf(conversionstring, sizeof(conversionstring), "%s", " (output format: 6to4)");
+				break;
+		};
+
+		break;
+
+	    case IPV6CALC_PROTO_IPV6:
+		External_type = EXTERNAL_DB_IPV6_COUNTRYCODE;
+		protocol = '6';
+		key_format = IPV6CALC_DB_LOOKUP_DATA_DBD_FORMAT_SEMICOLON_SEP_HEX_32x4;
+
+		if (filter_master->filter_ipv6addr.active == 0) {
+			ERRORPRINT_NA("no IPv6 filter provided (-E ...)");
+			return (1);
+		};
+
+		if (filter_master->filter_ipv6addr.filter_db_cc.active == 0) {
+			ERRORPRINT_NA("no IPv6 Database CountryCode filter provided (-E ipv6.db.cc=<CountryCode>)");
+			return (1);
+		};
+
+		if (filter_master->filter_ipv6addr.filter_db_asn.active != 0) {
+			ERRORPRINT_NA("IPv6 ASN filter currently not supported for database dump");
+			return (1);
+		};
+
+		if (filter_master->filter_ipv6addr.filter_db_registry.active != 0) {
+			ERRORPRINT_NA("IPv6 Registry filter currently not supported for database dump");
+			return (1);
+		};
+
+		if (filter_master->filter_ipv6addr.filter_typeinfo.active != 0) {
+			ERRORPRINT_NA("IPv6 TypeInfo filter currently not supported for database dump");
+			return (1);
+		};
+
+		if (filter_master->filter_ipv6addr.filter_typeinfo2.active != 0) {
+			ERRORPRINT_NA("IPv6 TypeInfo filter currently not supported for database dump");
+			return (1);
+		};
+
+		if (filter_master->filter_ipv6addr.filter_addr.active != 0) {
+			ERRORPRINT_NA("IPv6 Address filter currently not supported for database dump");
+			return (1);
+		};
+
+		filter_db_cc = &filter_master->filter_ipv6addr.filter_db_cc;
+
+		// check for supported outputtype
+		switch (outputtype) {
+			case FORMAT_ipv6addr:
+			case FORMAT_undefined:
+				// supported
+				break;
+
+			default:
+				ERRORPRINT_WA("Outputtype for IPv6 Address is not supported: 0x%08x", outputtype);
+				return (1);
+				break;
+		};
+
+		break;
+
+	    default:
+		ERRORPRINT_WA("unsupported selector: %d (FIX CODE)", selector);
+		return (1);
+		break;
+	};
+
+	// check for unsupported mixed filter
+	if ((filter_db_cc->cc_must_have_max > 0) && (filter_db_cc->cc_may_not_have_max > 0)) {
+		ERRORPRINT_NA("mixed Database filter with 'must-have' and 'may-not-have' is senseless for database dump");
+		return (1);
+	};
+
+	// create filter info string
+	snprintf(resultstring, sizeof(resultstring), "%s", ""); // clear string
+
+	if (filter_db_cc->cc_must_have_max > 0) {
+		for (i = 0; i < filter_db_cc->cc_must_have_max; i++) {
+			libipv6calc_db_wrapper_country_code_by_cc_index(cc2, sizeof(cc2), filter_db_cc->cc_must_have[i]);
+			snprintf(tempstring, sizeof(tempstring), "%s %s", filterstring, cc2); 
+			snprintf(filterstring, sizeof(filterstring), "%s", tempstring);
+		};
+	};
+
+	if (filter_db_cc->cc_may_not_have_max > 0) {
+		for (i = 0; i < filter_db_cc->cc_may_not_have_max; i++) {
+			libipv6calc_db_wrapper_country_code_by_cc_index(cc2, sizeof(cc2), filter_db_cc->cc_may_not_have[i]);
+			snprintf(tempstring, sizeof(tempstring), "%s ^%s", filterstring, cc2); 
+			snprintf(filterstring, sizeof(filterstring), "%s", tempstring);
+		};
+	};
+
+	// data-info
+	dbp = libipv6calc_db_wrapper_External_open_type(External_type, &recno_max);
+
+	if (dbp == NULL) {
+		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_External, "Error opening External by type");
+		goto END_libipv6calc_db_wrapper;
+	};
+
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "database opened type=%x recno_max=%ld dbp=%p", External_type | 0x40000, recno_max, dbp);
+
+	NONQUIETPRINT_WA("# 'External' database dump (with %lu entries) start with filter IPv%c && CountryCode(s):%s%s (suppress this line with option '-q')", recno_max, protocol, filterstring, conversionstring); // filterstring has a trailing space
+
+
+	// print header for 'ipset'
+	// family inet : IPv4
+	// family inet6: IPv6 and IPv4 converted by 6to4
+	if (print_ipset == 1) {
+		// create but don't care if already existing
+		fprintf(stdout, "create %s hash:net family %s counters -exist\n", name_ipset,
+			(selector == IPV6CALC_PROTO_IPV6) ? "inet6" : (
+				(outputtype == FORMAT_ipv6to4) ? "inet6" : "inet")
+		);
+
+		// flush ipset
+		fprintf(stdout, "flush %s\n", name_ipset);
+	};
+
+	for (recno = 1; recno <= recno_max; recno++) {
+		result = libipv6calc_db_wrapper_bdb_fetch_row(
+			dbp,			// pointer to database
+			key_format,		// key format
+			recno,			// row number
+			&value_first_00_31,     // data 1 (MSB in case of 64 bits)
+			&value_first_32_63,     // data 1 (LSB in case of 64 bits)
+			&value_last_00_31,      // data 2 (MSB in case of 64 bits)
+			&value_last_32_63,      // data 2 (LSB in case of 64 bits)
+			resultstring		// data ptr
+		);
+
+		if (result < 0) {
+			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "no entry found for recno=%ld", recno);
+			goto END_libipv6calc_db_wrapper;
+		};
+
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "resultstring=%s", resultstring);
+
+		int16_t cc_index = libipv6calc_db_wrapper_cc_index_by_country_code(resultstring);
+
+		switch (selector) {
+		    case IPV6CALC_PROTO_IPV4:
+			// countrycode shortcut filter
+			if (libipv6calc_db_cc_filter(cc_index, filter_db_cc) > 0) {
+				continue;
+			};
+
+			count++;
+			libipaddr_clearall(&ipaddr);
+			ipaddr.proto = IPV6CALC_PROTO_IPV4;
+			ipaddr.addr[0] = value_first_00_31;
+
+			// convert start/end into prefix length
+			delta = value_last_00_31 - value_first_00_31;
+
+			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "# IPv4 start=0x%08x end=0x%08x CC: %s", value_first_00_31, value_last_00_31, resultstring);
+
+			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "entry (main   ): ipv4=0x%08x delta=0x%08x", ipaddr.addr[0], delta);
+
+			// backfill with smaller segments if necessary
+			int split = 0;
+			while (delta > 0) {
+				DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "entry (analzye): ipv4=0x%08x delta=0x%08x split=%d", ipaddr.addr[0], delta, split);
+				// calculate base mask from delta
+				prefixlength = 32;
+				mask = 0xffffffff;
+				while (delta >= ~mask) {
+					mask <<= 1;
+					prefixlength--;
+				};
+				mask = ~((~mask) >> 1);
+				prefixlength++;
+
+				DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "entry (check  ): ipv4=0x%08x delta=0x%08x split=%d mask=0x%08x prefixlength=%d", ipaddr.addr[0], delta, split, mask, prefixlength);
+
+				// check whether mask is aligned
+				while ((ipaddr.addr[0] & mask) != ipaddr.addr[0]) {
+					// increase mask/prefixlength
+					mask = ~((~mask) >> 1);
+					prefixlength++;
+                                };
+
+				ipaddr.prefixlength = prefixlength;
+				ipaddr.flag_valid = 1;
+				ipaddr.flag_prefixuse = 1;
+
+				DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "entry (aligned): ipv4=0x%08x delta=0x%08x split=%d mask=0x%08x prefixlength=%d", ipaddr.addr[0], delta, split, mask, prefixlength);
+
+				switch (outputtype) {
+					case FORMAT_ipv6to4:
+						CONVERT_IPADDR_IPV4ADDR(ipaddr, ipv4addr);
+						retval = librfc3056_ipv4addr_to_ipv6to4addr(&ipv6addr, &ipv4addr);
+						CONVERT_IPV6ADDR_IPADDR(ipv6addr, ipaddr2);
+						libipaddr_ipaddrstruct_to_string(&ipaddr2, tempstring, sizeof(tempstring), formatoptions);
+						break;
+
+					default:
+						libipaddr_ipaddrstruct_to_string(&ipaddr, tempstring, sizeof(tempstring), formatoptions);
+						break;
+				};
+
+				if (print_ipset == 1) {
+					fprintf(stdout, "add %s %s\n", name_ipset, tempstring);
+				} else {
+					fprintf(stdout, "%s\n", tempstring);
+				};
+
+				delta -= ~mask;
+				if (delta == 0) {
+					// all covered, finished
+					break;
+				};
+
+				delta--;
+				ipaddr.addr[0] += ~mask + 1;
+				split++;
+			};
+
+			break;
+
+		    case IPV6CALC_PROTO_IPV6:
+			// countrycode shortcut filter
+			if (libipv6calc_db_cc_filter(cc_index, filter_db_cc) > 0) {
+				continue;
+			};
+
+			count++;
+			libipaddr_clearall(&ipaddr);
+			ipaddr.proto = IPV6CALC_PROTO_IPV6;
+			ipaddr.addr[0] = value_first_00_31;
+			ipaddr.addr[1] = value_first_32_63;
+
+			// convert mask into prefix length
+			prefixlength = libipv6calc_bitcount_uint32_t(value_last_00_31);
+
+			if (prefixlength == 32) {
+				// continue with 2nd block
+				prefixlength += libipv6calc_bitcount_uint32_t(value_last_32_63);
+			};
+
+			ipaddr.prefixlength = prefixlength;
+			ipaddr.flag_valid = 1;
+			ipaddr.flag_prefixuse = 1;
+			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "# IPv6 prefix=%08x:%08x mask=%08x:%08x prefixlength=%d CC: %s", value_first_00_31, value_first_32_63, value_last_00_31, value_last_32_63, prefixlength, resultstring);
+
+			libipaddr_ipaddrstruct_to_string(&ipaddr, tempstring, sizeof(tempstring), formatoptions);
+
+			if (print_ipset == 1) {
+				fprintf(stdout, "add %s %s\n", name_ipset, tempstring);
+			} else {
+				fprintf(stdout, "%s\n", tempstring);
+			};
+			break;
+		};
+	};
+
+
+	EXTERNAL_DB_USAGE_MAP_TAG(External_type);
+	retval = 0;
+
+END_libipv6calc_db_wrapper:
+	NONQUIETPRINT_WA("# 'External' database dump finished displaying %lu entries with filter IPv%c && CountryCode(s):%s%s (suppress this line with option '-q')", count, protocol, filterstring, conversionstring); // filterstring has a trailing space
+
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "retval=%d", retval);
+	return(retval);
+};
+
 #endif //SUPPORT_EXTERNAL
