@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_External.h
- * Version    : $Id: 43c9f89cd7bae958dfc5c3af318b98bd71875557 $
- * Copyright  : 2013-2017 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 0e4c749ebaa355f9dcc80a5e561fdb43084f6463 $
+ * Copyright  : 2013-2021 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file for libipv6calc_db_wrapper_External.c
@@ -10,6 +10,7 @@
 
 #include <time.h>
 #include "ipv6calctypes.h"
+#include "libipaddr.h"
 
 #ifndef _libipv6calc_db_wrapper_External_h
 
@@ -26,8 +27,8 @@
 static const db_file_desc libipv6calc_db_wrapper_External_db_file_desc[] = {
 	{ EXTERNAL_DB_IPV4_REGISTRY   , "ipv6calc-external-ipv4-registry.db"      , "IPv4 Registry"    , IPV6CALC_DB_IPV4_TO_REGISTRY | IPV6CALC_DB_EXTERNAL_IPV4 | IPV6CALC_DB_IPV4_TO_INFO },
 	{ EXTERNAL_DB_IPV6_REGISTRY   , "ipv6calc-external-ipv6-registry.db"      , "IPv6 Registry"    , IPV6CALC_DB_IPV6_TO_REGISTRY | IPV6CALC_DB_EXTERNAL_IPV6 | IPV6CALC_DB_IPV6_TO_INFO },
-	{ EXTERNAL_DB_IPV4_COUNTRYCODE, "ipv6calc-external-ipv4-countrycode.db"   , "IPv4 CountryCode" , IPV6CALC_DB_IPV4_TO_CC       | IPV6CALC_DB_EXTERNAL_IPV4 },
-	{ EXTERNAL_DB_IPV6_COUNTRYCODE, "ipv6calc-external-ipv6-countrycode.db"   , "IPv6 CountryCode" , IPV6CALC_DB_IPV6_TO_CC       | IPV6CALC_DB_EXTERNAL_IPV6 },
+	{ EXTERNAL_DB_IPV4_COUNTRYCODE, "ipv6calc-external-ipv4-countrycode.db"   , "IPv4 CountryCode" , IPV6CALC_DB_IPV4_TO_CC       | IPV6CALC_DB_EXTERNAL_IPV4 | IPV6CALC_DB_IPV4_DUMP_CC },
+	{ EXTERNAL_DB_IPV6_COUNTRYCODE, "ipv6calc-external-ipv6-countrycode.db"   , "IPv6 CountryCode" , IPV6CALC_DB_IPV6_TO_CC       | IPV6CALC_DB_EXTERNAL_IPV6 | IPV6CALC_DB_IPV6_DUMP_CC },
 };
 
 // features
@@ -66,7 +67,7 @@ extern time_t      libipv6calc_db_wrapper_External_db_unixtime_by_feature(uint32
 
 #include <db.h>
 
-extern char external_db_dir[NI_MAXHOST];
+extern char external_db_dir[PATH_MAX];
 
 extern int          libipv6calc_db_wrapper_External_db_avail(const unsigned int type);
 extern DB          *libipv6calc_db_wrapper_External_open_type(const unsigned int type, long int *db_recno_max_ptr);
@@ -82,4 +83,7 @@ extern int libipv6calc_db_wrapper_External_country_code_by_addr(const ipv6calc_i
 // IPv4/v6 Info
 extern int libipv6calc_db_wrapper_External_info_by_ipaddr(const ipv6calc_ipaddr *ipaddrp, char *string, const size_t string_len);
 
+// Database dump
+extern int libipv6calc_db_wrapper_External_dump(const int selector, const s_ipv6calc_filter_master *filter_master, const uint32_t outputtype, const uint32_t formatoptions, const char *name_ipset);
+
 #endif
