@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_GeoIP2.c
- * Version    : $Id: bde02da0fbec8a8c3f8966aae04086d08aec5730 $
+ * Version    : $Id: cf6ecb9284d4a82fc1056f206c90dd1f330f22dc $
  * Copyright  : 2019-2021 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -359,7 +359,7 @@ int libipv6calc_db_wrapper_GeoIP2_wrapper_cleanup(void) {
 void libipv6calc_db_wrapper_GeoIP2_wrapper_info(char* string, const size_t size) {
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "Called");
 
-	snprintf(string, size, "GeoIP2 available databases: Country4=%d Country6=%d ASN4=%d ASN6=%d City4=%d City6=%d", \
+	snprintf(string, size, "GeoIP2 database support: Country4=%d Country6=%d ASN4=%d ASN6=%d City4=%d City6=%d", \
 		(wrapper_features & IPV6CALC_DB_IPV4_TO_CC) ? 1 : 0, \
 		(wrapper_features & IPV6CALC_DB_IPV6_TO_CC) ? 1 : 0, \
 		(wrapper_features & IPV6CALC_DB_IPV4_TO_AS) ? 1 : 0, \
