@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_MMDB.c
- * Version    : $Id: 7ae68cc74849623c5d9aa9db9a59cf153a6f9033 $
- * Copyright  : 2019-2019 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 239da87caeecd331a6074c5f9fd07dedee2023ea $
+ * Copyright  : 2019-2021 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  ipv6calc MaxMindDB database wrapper
@@ -26,7 +26,7 @@
 #include "libipv6calc_db_wrapper_MMDB.h"
 
 #ifdef SUPPORT_MMDB_DYN
-char mmdb_lib_file[NI_MAXHOST] = MMDB_DYN_LIB;
+char mmdb_lib_file[PATH_MAX] = MMDB_DYN_LIB;
 static const char* wrapper_mmdb_info = "dyn-load";
 
 /* define status and dynamic load functions */
@@ -762,10 +762,17 @@ MMDB_lookup_result_s libipv6calc_db_wrapper_MMDB_wrapper_lookup_by_addr (const i
 		su.in.sin_addr.s_addr = htonl(ipaddrp->addr[0]);
 	} else if (ipaddrp->proto == 6) {
 		su.sockaddr.sa_family = AF_INET6;
+#ifdef __KAME__ // FreeBSD misses s6_addr8/16/32 in non-kernel include, also union has different name in glibc (__in6_u vs.  __u6_addr) :-(
+		su.in6.sin6_addr.__u6_addr.__u6_addr32[0] = htonl(ipaddrp->addr[0]);
+		su.in6.sin6_addr.__u6_addr.__u6_addr32[1] = htonl(ipaddrp->addr[1]);
+		su.in6.sin6_addr.__u6_addr.__u6_addr32[2] = htonl(ipaddrp->addr[2]);
+		su.in6.sin6_addr.__u6_addr.__u6_addr32[3] = htonl(ipaddrp->addr[3]);
+#else
 		su.in6.sin6_addr.s6_addr32[0] = htonl(ipaddrp->addr[0]);
 		su.in6.sin6_addr.s6_addr32[1] = htonl(ipaddrp->addr[1]);
 		su.in6.sin6_addr.s6_addr32[2] = htonl(ipaddrp->addr[2]);
 		su.in6.sin6_addr.s6_addr32[3] = htonl(ipaddrp->addr[3]);
+#endif
 	} else {
 		*mmdb_error = MMDB_INVALID_DATA_ERROR;
 		goto END_libipv6calc_db_wrapper;
@@ -958,7 +965,7 @@ int libipv6calc_db_wrapper_MMDB_all_by_addr(const ipv6calc_ipaddr *ipaddrp, libi
 	MMDB_entry_data_s entry_data;
 	int mmdb_error;
 
-	static char resultstring[NI_MAXHOST];
+	static char resultstring[IPV6CALC_STRING_MAX];
 
 	libipv6calc_db_wrapper_geolocation_record_clear(recordp);
 
@@ -974,10 +981,17 @@ int libipv6calc_db_wrapper_MMDB_all_by_addr(const ipv6calc_ipaddr *ipaddrp, libi
 		su.in.sin_addr.s_addr = htonl(ipaddrp->addr[0]);
 	} else if (ipaddrp->proto == 6) {
 		su.sockaddr.sa_family = AF_INET6;
+#ifdef __KAME__ // FreeBSD misses s6_addr8/16/32 in non-kernel include, also union has different name in glibc (__in6_u vs.  __u6_addr) :-(
+		su.in6.sin6_addr.__u6_addr.__u6_addr32[0] = htonl(ipaddrp->addr[0]);
+		su.in6.sin6_addr.__u6_addr.__u6_addr32[1] = htonl(ipaddrp->addr[1]);
+		su.in6.sin6_addr.__u6_addr.__u6_addr32[2] = htonl(ipaddrp->addr[2]);
+		su.in6.sin6_addr.__u6_addr.__u6_addr32[3] = htonl(ipaddrp->addr[3]);
+#else
 		su.in6.sin6_addr.s6_addr32[0] = htonl(ipaddrp->addr[0]);
 		su.in6.sin6_addr.s6_addr32[1] = htonl(ipaddrp->addr[1]);
 		su.in6.sin6_addr.s6_addr32[2] = htonl(ipaddrp->addr[2]);
 		su.in6.sin6_addr.s6_addr32[3] = htonl(ipaddrp->addr[3]);
+#endif
 	} else {
 		mmdb_error = MMDB_INVALID_DATA_ERROR;
 		goto END_libipv6calc_db_wrapper;
