@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# $Id: generate.sh,v 1.4 2011/10/29 08:35:24 peter Exp $
+# $Id: 19718dd1c7adc7391f458b78a0cd8d3894390420 $
 
 # Requires: opensp
 
@@ -51,13 +51,16 @@ create_html_singlepage() {
 	echo "INF: Create HTML singlepage '$file_html'"
 	set -x
 	jade -t sgml -i html -V nochunks -d "${file_dsl}#html" $file_sgml >$file_html
-	set +x
 	local retval=$?
+	set +x
 	if [ $retval -eq 0 ]; then
-		echo "INF: Create HTML singlepage - done"
-	else
-		echo "ERR: Create HTML singlepage - an error occurs!"
+		if head -1 $file_html | grep -q DOCTYPE; then
+			echo "INF: Create HTML singlepage - done"
+			return 0
+		fi
 	fi
+
+	echo "ERR: Create HTML singlepage - an error occurs!"
 	return $retval
 }
 
