@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc/ipv6calc
  * File       : ipv6calc/ipv6calcoptions.h
- * Version    : $Id: 22ecc5c1bf43c7cacd310aa991469bdbb70728d7 $
- * Copyright  : 2002-2019 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 985241dc676e236ad924c33b7cdc07b188c30305 $
+ * Copyright  : 2002-2021 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file containing options for ipv6calc
@@ -97,6 +97,9 @@ static struct option ipv6calc_longopts[] = {
 	{ "printcompressed"      , 0, NULL, FORMATOPTION_NUM_printcompressed       + FORMATOPTION_NUM_HEAD },
 	{ "printuncompressed"    , 0, NULL, FORMATOPTION_NUM_printuncompressed     + FORMATOPTION_NUM_HEAD },
 	{ "printfulluncompressed", 0, NULL, FORMATOPTION_NUM_printfulluncompressed + FORMATOPTION_NUM_HEAD },
+
+	{ "no-prefixlength"      , 0, NULL, FORMATOPTION_NUM_no_prefixlength + FORMATOPTION_NUM_HEAD },
+	{ "force-prefix"         , 1, NULL, FORMATOPTION_NUM_forceprefix + FORMATOPTION_NUM_HEAD },
 	
 	{ "machine_readable"     , 0, NULL, FORMATOPTION_NUM_machinereadable + FORMATOPTION_NUM_HEAD },
 	// { "quiet"                , 0, NULL, FORMATOPTION_NUM_quiet + FORMATOPTION_NUM_HEAD }, strange duplicate
@@ -113,6 +116,10 @@ static struct option ipv6calc_longopts[] = {
 
 	{ "print-iid-var"        , 0, NULL, FORMATOPTION_NUM_print_iid_var + FORMATOPTION_NUM_HEAD },
 
+	{ "print-octal"		 , 0, NULL, FORMATOPTION_NUM_print_octal + FORMATOPTION_NUM_HEAD },
+
+	{ "print-ipset"		 , 1, NULL, FORMATOPTION_NUM_print_ipset + FORMATOPTION_NUM_HEAD },
+
 	/* new options */
 	{ "in"        , 1, NULL, CMD_inputtype  },
 	{ "out"       , 1, NULL, CMD_outputtype },
