@@ -1,9 +1,8 @@
-#!/bin/sh
+#!/usr/bin/env bash
 #
 # Project    : ipv6calc
 # File       : test_scenarios.sh
-# Version    : $Id: 3cd87b9a1f8a5d950f58d05629f21b0cd29d0108 $
-# Copyright  : 2001-2017 by Peter Bieringer <pb (at) bieringer.de>
+# Copyright  : 2001-2023 by Peter Bieringer <pb (at) bieringer.de>
 # License    : GPLv2
 #
 # Test patterns for ipv6calc (functions only)
@@ -66,10 +65,10 @@ testscenarios_ipv4_reserved() {
 	cat <<END | grep -v '^#'
 0.0.0.0			RFC1122#3.2.1.3
 0.255.255.255		RFC1122#3.2.1.3
-9.255.255.255		noRFC
+9.255.255.255		noRFC		skip-anon-test
 10.0.0.0		RFC1918#3
 10.255.255.255		RFC1918#3
-11.0.0.0		noRFC
+11.0.0.0		noRFC		skip-anon-test
 100.63.255.255		noRFC
 100.64.0.0		RFC6598
 100.127.255.255		RFC6598
@@ -77,7 +76,7 @@ testscenarios_ipv4_reserved() {
 126.255.255.255		noRFC
 127.0.0.0		RFC1122#3.2.1.3
 127.255.255.255		RFC1122#3.2.1.3
-128.0.0.0		noRFC
+128.0.0.0		noRFC		skip-anon-test
 169.253.255.255		noRFC
 169.254.0.0		RFC3927#1
 169.254.255.255		RFC3927#1
@@ -94,7 +93,7 @@ testscenarios_ipv4_reserved() {
 192.0.2.0		RFC5737#1
 192.0.2.255		RFC5737#1
 192.0.3.0		noRFC
-192.88.98.255		noRFC
+192.88.98.255		noRFC		skip-anon-test
 192.88.99.0		RFC3068#2.3
 192.88.99.255		RFC3068#2.3
 192.88.100.0		noRFC		skip-anon-test
@@ -106,7 +105,7 @@ testscenarios_ipv4_reserved() {
 198.18.0.0		RFC2544#C.2.2
 198.19.255.255		RFC2544#C.2.2
 198.20.0.0		noRFC
-198.51.99.255		noRFC
+198.51.99.255		noRFC		skip-anon-test
 198.51.100.0		RFC5737#3
 198.51.100.255		RFC5737#3
 198.51.101.0		noRFC		skip-anon-test
@@ -345,14 +344,23 @@ testscenarios_anonymization_options() {
 --anonymize-preset zc		00:02:b3:ff:fe:ff:ff:ff=00:02:b3:ff:fe:00:00:00
 # EUI-64: global (OUI-36)
 --anonymize-preset zc		00:1b:c5:03:df:ff:ff:ff=00:1b:c5:03:d0:00:00:00
+--anonymize-preset zc		70:b3:d5:f7:19:87:65:43=70:b3:d5:f7:10:00:00:00
 # EUI-64: global (OUI-36) expanded EUI-48
 --anonymize-preset zc		00:1b:c5:ff:fe:03:df:ff=00:1b:c5:ff:fe:03:d0:00
 --anonymize-preset zc --mask-eui64 16 --mask-autoadjust no	00:1b:c5:ff:fe:03:df:ff=00:1b:00:00:00:00:00:00
+# EUI-64: global (OUI-28)
+--anonymize-preset zc		a0:3e:6b:23:67:01:43:21=a0:3e:6b:20:00:00:00:00
+--anonymize-preset zc		b4:a2:eb:b9:87:65:43:21=b4:a2:eb:b0:00:00:00:00
 # EUI-48: global (OUI-24)
 --anonymize-preset zc		00:02:b3:ff:ff:ff=00:02:b3:00:00:00
+--anonymize-preset zc		00:50:56:01:23:45=00:50:56:00:00:00
 # EUI-48: global (OUI-36)
 --anonymize-preset zc		00:1b:c5:03:df:ff=00:1b:c5:03:d0:00
+--anonymize-preset zc		70:b3:d5:f7:19:87=70:b3:d5:f7:10:00
 --anonymize-preset zc --mask-mac 16 --mask-autoadjust no	00:1b:c5:03:df:ff=00:1b:00:00:00:00
+# EUI-48: global (OUI-28)
+--anonymize-preset zc		a0:3e:6b:23:67:01=a0:3e:6b:20:00:00
+--anonymize-preset zc		b4:a2:eb:b9:87:65=b4:a2:eb:b0:00:00
 # LISP Anycast
 --mask-ipv6 16				2001:67c:198:f123:0123:4567:89ab:cdef=2001:67c:198:a909:a949:4291:c02d:5d13
 --mask-ipv6 24				2001:67c:198:f123:0123:4567:89ab:cdef=2001:67c:198:a909:a949:4291:c02d:5d13
@@ -372,15 +380,23 @@ END
 testscenarios_anonymization_options_kp() {
 	cat <<END | grep -v '^#'
 --anonymize-preset kp			46.244.223.233=242.222.34.63
---anonymize-preset kp			2001:0a60:11e1:9501:e876:aee4:0721:e8ac=a909:16fa:9092:23ff:a909:4941::7
+--anonymize-preset kp			2a04:8000:11e1:9501:e876:aee4:0721:e8ac=a909:118a:90a0:d40f:a909:4941:0:7
 --anonymize-preset kp			::2.2.3.4=::253.134.12.143
 --anonymize-preset kp			::ffff:2.2.3.4=::ffff:253.134.12.143
 --anonymize-preset kp			::1=::1
 --anonymize-preset kp			3ffe:831f:ce49:7601:8000:efff:af4a:86bf=3ffe:831f:ce49:7601:8000:ffff:a0b:f33a
 --anonymize-preset kp			64:ff9b::0202:0304=64:ff9b::fd86:c8f
 --anonymize-preset kp			2001:0db8:0000:0000:81c0:0f3f:c807:1455=2001:db8::a909:4941:0:7
+# EUI-48 OUI-24/28/36
+--anonymize-preset kp			fd00:bbbb:bbbb:1:265e:beff:fe12:3456=fd00:bbbb:bbbb:9:a929:4291:4265:ebee
+--anonymize-preset kp			fd00:bbbb:bbbb:1:0250:c2ff:fe12:3456=fd00:bbbb:bbbb:9:a929:4291:5021:1234
+--anonymize-preset kp			fd00:bbbb:bbbb:1:0255:daff:fe12:3456=fd00:bbbb:bbbb:9:a929:4291:5030:1001
+# EUI-64 OUI-24/28/36
+--anonymize-preset kp			fd00:bbbb:bbbb:1:265e:be12:3456:789a=fd00:bbbb:bbbb:9:a929:4291:6265:ebeb
+--anonymize-preset kp			fd00:bbbb:bbbb:1:0250:c212:3456:789a=fd00:bbbb:bbbb:9:a929:4291:7021:123c
+--anonymize-preset kp			fd00:bbbb:bbbb:1:0255:da12:3456:789a=fd00:bbbb:bbbb:9:a929:4291:7030:1001
 # do not anonymize LISP anycast prefix
---anonymize-preset kp			2001:67c:198::1=2001:67c:198::a909:4291:c02d:5d1d
+--anonymize-preset kp			2001:67c:198::1=2001:67c:198:0:a909:4291:c02d:5d1d
 END
 }
 
@@ -392,6 +408,8 @@ testscenarios_showinfo() {
 00:1b:c5:06:a3:45	EUI48_SCOPE=global
 00:50:c2:86:23:45	OUI="Elsys AG"
 00:50:c2:86:23:45	EUI48_SCOPE=global
+52:54:00:01:23:45	OUI="possible QEMU VM"
+00:50:56:01:23:45	OUI="VMware, Inc. (possible VMware VM)"
 00:02:b3:01:23:45:67:89	OUI="Intel Corporation"
 00:02:b3:01:23:45:67:89	EUI64_SCOPE=global
 00:1b:c5:06:a3:45:67:89	OUI="IST GmbH"
@@ -435,6 +453,8 @@ a909:16fa:9092:23ff:a909:4941::7	IPV6_REGISTRY=RIPENCC
 2a01:238:423d:8800:85b3:9e6b:3019:8909	"ipv6,unicast,global-unicast,productive,iid-random,iid,iid-local"|--mrqva --mrtvo IPV6_TYPE
 2a01:238:423d:8800:85b3:9e6b:3019:8909	ipv6,unicast,global-unicast,productive,iid-random,iid,iid-local|--mrqvn --mrtvo IPV6_TYPE
 2a01:238:423d:8800:85b3:9e6b:3019:8909	IPV6_TYPE=ipv6,unicast,global-unicast,productive,iid-random,iid,iid-local|--mrst IPV6_TYPE
+1.2.3.4					ipv4,unicast,global|--mrtvo IPV._TYPE
+2a01::1					ipv6,unicast,global-unicast,productive,iid,iid-local|--mrtvo IPV._TYPE
 # 6rd
 2001:b4c:0:2010::/60			IPV4[192.0.2.1]=192.0.2.1|--6rd_prefixlength 28
 2001:b4e:0:1008::/61			IPV4[192.0.2.1]=192.0.2.1|--6rd_prefixlength 29
@@ -492,10 +512,8 @@ END
 
 testscenarios_showinfo_DBIPv6() {
 	cat <<END | grep -v '^#'
-# match first entry in database (db-ip.com assigns unusued range to US)
-2000:000:0000:0123:0123:4567:89ab:cdef	IPV6_COUNTRYCODE=US
-# match first entry in database (db-ip.com assigns unusued range to US)
-3fff:000:0000:0123:0123:4567:89ab:cdef	IPV6_COUNTRYCODE=US
+# match first entry in database
+2001:4860:4860::8888			IPV6_COUNTRYCODE=US
 # non-anonymized IPv6 prefix
 2001:a60:113a:0123:0123:4567:89ab:cdef	IPV6_COUNTRYCODE=DE
 2001:a60:113a:0123:0123:4567:89ab:cdef	DBIP_COUNTRY_SHORT=DE
