@@ -1,24 +1,26 @@
-#!/bin/bash
+#!/usr/bin/env bash
 #
 # Project    : ipv6calc/ipv6calcweb
 # File       : test_ipv6calcweb.sh
-# Version    : $Id: 472981ae7d1375a27422c07f6bc8249e9631c515 $
-# Copyright  : 2012-2019 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: 625359ea7ba0db6df614426bf9e5aecf9ed82b1e $
+# Copyright  : 2012-2021 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Information:
 #  Test script for ipv6calcweb
 #
 
+verbose=false
+opt_debug=false
 while getopts "Vf:d" opt; do
 	case $opt in
 	    f)
 		opt_format="$OPTARG"
 		;;
 	    d)
-		opt_debug=1
+		opt_debug=true
 		;;
 	    V)
-		verbose=1
+		verbose=true
 		;;
 	    *)
 		echo "$0 [-V] [-d] [-f <format>]"
@@ -40,15 +42,17 @@ fi
 if [ ! -f ipv6calcweb.cgi ]; then
 	make || exit 1
 fi
-if [ ! -x ipv6calcweb.cgi ]; then
-	chmod u+x ipv6calcweb.cgi
+
+if [ "$OSTYPE" = "linux-gnu" ]; then
+	# Linux has no issues -T (but FreeBSD)
+	perlopt=" -T"
 fi
 
 ## check for empty stderr
 export HTTP_IPV6CALCWEB_DEBUG="0x5000" # no sleeps and no Anti-DoS
 
 set -x
-stderr=$(HTTP_IPV6CALCWEB_OUTPUT_FORMAT=html HTTP_IPV6CALCWEB_OUTPUT_FORMAT_HTML_DB=subcolumns REMOTE_ADDR=50.60.70.80 ./ipv6calcweb.cgi 2>&1 >/dev/null)
+stderr=$(HTTP_IPV6CALCWEB_OUTPUT_FORMAT=html HTTP_IPV6CALCWEB_OUTPUT_FORMAT_HTML_DB=subcolumns REMOTE_ADDR=50.60.70.80 perl -w $perlopt ipv6calcweb.cgi 2>&1 >/dev/null)
 set +x
 if [ -n "$stderr" ]; then
 	echo "ERROR : stderr not empty: $stderr"
@@ -56,7 +60,7 @@ if [ -n "$stderr" ]; then
 fi
 
 set -x
-stderr=$(HTTP_IPV6CALCWEB_OUTPUT_FORMAT=html HTTP_IPV6CALCWEB_OUTPUT_FORMAT_HTML_DB=sequential REMOTE_ADDR=50.60.70.80 ./ipv6calcweb.cgi 2>&1 >/dev/null)
+stderr=$(HTTP_IPV6CALCWEB_OUTPUT_FORMAT=html HTTP_IPV6CALCWEB_OUTPUT_FORMAT_HTML_DB=sequential REMOTE_ADDR=50.60.70.80 perl -w $perlopt ipv6calcweb.cgi 2>&1 >/dev/null)
 set +x
 if [ -n "$stderr" ]; then
 	echo "ERROR : stderr not empty: $stderr"
@@ -64,7 +68,7 @@ if [ -n "$stderr" ]; then
 fi
 
 set -x
-stderr=$(HTTP_IPV6CALCWEB_OUTPUT_FORMAT=text REMOTE_ADDR=50.60.70.80 ./ipv6calcweb.cgi 2>&1 >/dev/null)
+stderr=$(HTTP_IPV6CALCWEB_OUTPUT_FORMAT=text REMOTE_ADDR=50.60.70.80 perl -w $perlopt ipv6calcweb.cgi 2>&1 >/dev/null)
 set +x
 if [ -n "$stderr" ]; then
 	echo "ERROR : stderr not empty: $stderr"
@@ -82,31 +86,31 @@ for format in textkeyvalue text html htmlfull; do
 
 	export HTTP_IPV6CALCWEB_DEBUG="0x5000" # no sleeps and no Anti-DoS
 
-	[ "$verbose" = "1" ] && echo "INFO  : test format: $format"
-	[ "$verbose" = "1" ] && echo "DEBUG : execute: HTTP_IPV6CALCWEB_DEBUG=$HTTP_IPV6CALCWEB_DEBUG HTTP_IPV6CALCWEB_OUTPUT_FORMAT=\"$format\" ./ipv6calcweb.cgi"
+	$verbose && echo "INFO  : test format: $format"
+	$verbose && echo "DEBUG : execute: HTTP_IPV6CALCWEB_DEBUG=$HTTP_IPV6CALCWEB_DEBUG HTTP_IPV6CALCWEB_OUTPUT_FORMAT=\"$format\" perl -w $perlopt ipv6calcweb.cgi"
 
-	if [ "$opt_debug" = "1" ]; then
-		HTTP_IPV6CALCWEB_OUTPUT_FORMAT="$format" ./ipv6calcweb.cgi
+	if $opt_debug; then
+		HTTP_IPV6CALCWEB_OUTPUT_FORMAT="$format" perl -w $perlopt ipv6calcweb.cgi
 		rc=$?
 	else
-		if [ "$verbose" = "1" ]; then
-			HTTP_IPV6CALCWEB_OUTPUT_FORMAT="$format" ./ipv6calcweb.cgi >/dev/null
+		if $verbose; then
+			HTTP_IPV6CALCWEB_OUTPUT_FORMAT="$format" perl -w $perlopt ipv6calcweb.cgi >/dev/null
 			rc=$?
 		else
-			HTTP_IPV6CALCWEB_OUTPUT_FORMAT="$format" ./ipv6calcweb.cgi >/dev/null 2>/dev/null
+			HTTP_IPV6CALCWEB_OUTPUT_FORMAT="$format" perl -w $perlopt ipv6calcweb.cgi >/dev/null 2>/dev/null
 			rc=$?
 		fi
 	fi
 	if [ $rc -ne 0 ];then
 		echo "ERROR : output format reports an error: $format"
-		if [ "$opt_debug" != "1" ]; then
-			HTTP_IPV6CALCWEB_OUTPUT_FORMAT="$format" ./ipv6calcweb.cgi
+		if ! $opt_debug; then
+			HTTP_IPV6CALCWEB_OUTPUT_FORMAT="$format" perl -w $perlopt ipv6calcweb.cgi
 		fi
 		exit 1
 	fi
-	[ "$verbose" = "1" ] || echo -n "."
+	$verbose || echo -n "."
 done || exit 1
-[ "$verbose" = "1" ] || echo
+$verbose || echo
 echo "INFO  : $test successful"
 
 
@@ -140,31 +144,32 @@ for format in textkeyvalue text html htmlfull; do
 	HTTP_IPV6CALCWEB_OUTPUT_FORMAT="$format"
 	export HTTP_IPV6CALCWEB_OUTPUT_FORMAT
 
-	if [ "$verbose" = "1" ]; then
-		OUTPUT="`./ipv6calcweb.cgi`"
+	if $verbose; then
+		OUTPUT="`perl -w $perlopt ipv6calcweb.cgi`"
 		result=$?
 	else
-		OUTPUT="`./ipv6calcweb.cgi 2>&1`"
+		OUTPUT="`perl -w $perlopt ipv6calcweb.cgi 2>&1`"
 		result=$?
 	fi
-	if [ "$opt_debug" = "1" ]; then
+	if $opt_debug; then
 		echo "$OUTPUT"
 	fi
 
 	if [ $result -ne 0 ];then
 		echo "ERROR : output format reports an error: $format"
-		if [ "$opt_debug" != "1" ]; then
+		if ! $opt_debug; then
 			echo "$OUTPUT"
 		fi
 		exit 1
 	fi
-	[ "$verbose" = "1" ] || echo -n "."
+	$verbose || echo -n "."
 done || exit 1
-[ "$verbose" = "1" ] || echo
+$verbose || echo
 echo "INFO  : $test successful"
 
 
 ## test Anti-DoS implementation
+if [ -r /proc/loadavg ]; then
 test="run 'ipv6calcweb.cgi' Anti-DoS tests"
 echo "INFO  : $test"
 for e in  1 5 15 p; do
@@ -192,7 +197,7 @@ for e in  1 5 15 p; do
 
 	echo "INFO  : Anti-DoS test: $e"
 
-	output=$(./ipv6calcweb.cgi)
+	output=$(perl -w $perlopt ipv6calcweb.cgi)
 	rc=$?
 	if [ $rc -ne 1 ];then
 		echo "ERROR : Anti-DoS test reports unexpected error: rc=$rc"
@@ -207,8 +212,11 @@ for e in  1 5 15 p; do
 		exit 1
 	fi
 done || exit 1
-[ "$verbose" = "1" ] || echo
+$verbose || echo
 echo "INFO  : $test successful"
+else
+echo "NOTICE: AntiDDoS test skipped, /proc/loadavg missing"
+fi
 
 #if [ $result -ne 0 ]; then
 #	echo "TEST FAILED (exit code != 0)"
@@ -218,14 +226,14 @@ echo "INFO  : $test successful"
 #	exit 1
 #else
 #	# check output
-#	if echo "$OUTPUT" | egrep -q "(ERROR|problem)"; then
+#	if echo "$OUTPUT" | grep -Eq "(ERROR|problem)"; then
 #		echo "TEST FAILED (ERROR|problem) occurs"
 #		HTTP_IPV6CALCWEB_DEBUG="0xffff"
 #		export HTTP_IPV6CALCWEB_DEBUG
 #		./ipv6calcweb.cgi
 #		exit 1
 #	fi
-#	if echo "$OUTPUT" | egrep -q "(reserved)"; then
-#		[ "$verbose" = "1" ] || echo "$OUTPUT"
+#	if echo "$OUTPUT" | grep -Eq "(reserved)"; then
+#		$verbose || echo "$OUTPUT"
 #	fi
 #fi
