@@ -1,19 +1,19 @@
-#!/bin/sh
+#!/usr/bin/env bash
 #
 # Project    : ipv6calc/ipv6calcweb
 # File       : test_ipv6calcweb_form.sh
-# Version    : $Id: c84221f17dc17a138dd562db90872b5d8c6c6b68 $
-# Copyright  : 2012-2018 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: d3e0b4815fe4240d39e0c31b7020a3e7fedc39a9 $
+# Copyright  : 2012-2021 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Information:
 #  Test script for form mode of ipv6calcweb
 #
 
-verbose=0
+verbose=false
 while getopts "Vh\?" opt; do
 	case $opt in
 	    V)
-		verbose=1
+		verbose=true
 		;;
 	    *)
 		echo "$0 [-V]"
@@ -26,11 +26,16 @@ done
 # Test Scenarios for autodetection "good case"
 source ../ipv6calc/test_scenarios.sh
 
-if [ ! -x ipv6calcweb.cgi ]; then
+if [ ! -f ipv6calcweb.cgi ]; then
 	echo "ERROR : run make"
 	exit 1
 fi
 
+if [ "$OSTYPE" = "linux-gnu" ]; then
+	# Linux has no issues -T (but FreeBSD)
+	perlopt=" -T"
+fi
+
 REMOTE_ADDR="127.0.0.1"
 REMOTE_HOST="client.domain.example"
 HTTP_USER_AGENT="test_ipv6calcweb"
@@ -44,14 +49,14 @@ HTTP_IPV6CALCWEB_DEBUG="0x5000" # no sleeps and no Anti-DoS
 export REMOTE_ADDR REMOTE_HOST HTTP_USER_AGENT SERVER_ADDR SERVER_NAME QUERY_STRING HTTP_IPV6CALCWEB_MODE HTTP_IPV6CALCWEB_DEBUG
 
 # extract tokenhash & tokentime
-OUTPUT="`./ipv6calcweb.cgi`"
+OUTPUT="`perl -w $perlopt ipv6calcweb.cgi`"
 result=$?
 if [ $result -ne 0 ]; then
 	echo "TEST FAILED"
 	exit 1
 else
 	# check output
-	if echo "$OUTPUT" | egrep -q "(ERROR|problem)"; then
+	if echo "$OUTPUT" | grep -Eq "(ERROR|problem)"; then
 		echo "TEST FAILED"
 		exit 1
 	fi
@@ -70,41 +75,41 @@ if [ ${#tokentime} -ne 10 ]; then
 	exit 1
 fi
 
-[ "$verbose" = "1" ] && echo "DEBUG: extracted tokenhash: $tokenhash"
-[ "$verbose" = "1" ] && echo "DEBUG: extracted tokentime: $tokentime"
+$verbose && echo "DEBUG: extracted tokenhash: $tokenhash"
+$verbose && echo "DEBUG: extracted tokentime: $tokentime"
 
-test="run 'ipv6calcweb.cgi ' good tests"
+test="run 'ipv6calcweb.cgi' good tests"
 echo "INFO  : $test"
-testscenarios_auto_good | grep -v "^#" | egrep -vw "(bitstring|base85)" | grep -v "%" | while read input type; do
+testscenarios_auto_good | grep -v "^#" | grep -Evw "(bitstring|base85)" | grep -v "%" | while read input type; do
 	input_escaped="$(perl -MURI::Escape -e 'print uri_escape($ARGV[0]);' "$input")"
 	QUERY_STRING="input=$input_escaped&tokenhash=$tokenhash&tokentime=$tokentime"
 
-	[ "$verbose" = "1" ] && echo "Test: $input ($input_escaped) ($type)"
-	[ "$verbose" = "1" ] && echo "QUERY_STRING=$QUERY_STRING"
+	$verbose && echo "Test: $input ($input_escaped) ($type)"
+	$verbose && echo "QUERY_STRING=$QUERY_STRING"
 
 	export REMOTE_ADDR REMOTE_HOST HTTP_USER_AGENT SERVER_ADDR SERVER_NAME QUERY_STRING HTTP_IPV6CALCWEB_MODE
 
-	if [ "$verbose" = "1" ]; then 
-		OUTPUT="`./ipv6calcweb.cgi`"
+	if $verbose; then 
+		OUTPUT="`perl -w $perlopt ipv6calcweb.cgi`"
 		result=$?
 	else
-		OUTPUT=$(./ipv6calcweb.cgi 2>/dev/null)
+		OUTPUT=$(perl -w $perlopt ipv6calcweb.cgi 2>/dev/null)
 		result=$?
 	fi
 
-	[ "$verbose" = "1" ] && echo "Result: $result"
+	$verbose && echo "Result: $result"
 
 	if [ $result -ne 0 ]; then
 		echo "TEST FAILED"
 		exit 1
 	else
 		# check output
-		if echo "$OUTPUT" | egrep -q "(ERROR|problem)"; then
+		if echo "$OUTPUT" | grep -Eq "(ERROR|problem)"; then
 			echo "TEST FAILED"
 			exit 1
 		fi
 	fi
-	[ "$verbose" = "1" ] || echo -n "."
+	$verbose || echo -n "."
 done || exit $?
-[ "$verbose" = "1" ] || echo
+$verbose || echo
 echo "INFO  : $test successful"
