@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6loganon.c
- * Version    : $Id: 1579820ea06a7f0dfa78b04b1b4d18e7dddd6f48 $
- * Copyright  : 2007-2017 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: e63ca446249fe7b23a02ed913d83c0ec41a042e2 $
+ * Copyright  : 2007-2021 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile anonymization
@@ -55,7 +55,7 @@ int mask_mac;
 
 /* features */
 int feature_zeroize = 1; // always supported
-int feature_anon    = 1; // always supported
+int feature_anon    = 0; // will be checked later
 int feature_kp      = 0; // will be checked later
 int feature_kg      = 0; // will be checked later
 
@@ -72,14 +72,14 @@ static void lineparser();
 static int      cache_lru_max = 0;
 static int      cache_lru_last = 0;
 int      cache_lru_limit = 20; /* optimum */
-static char     cache_lru_key_token[CACHE_LRU_SIZE][NI_MAXHOST];
-static char     cache_lru_value[CACHE_LRU_SIZE][NI_MAXHOST];
+static char     cache_lru_key_token[CACHE_LRU_SIZE][IPV6CALC_STRING_MAX];
+static char     cache_lru_value[CACHE_LRU_SIZE][IPV6CALC_STRING_MAX];
 static long int cache_lru_statistics[CACHE_LRU_SIZE];
 
-char	file_out[NI_MAXHOST] = "";
+char	file_out[IPV6CALC_STRING_MAX] = "";
 int	file_out_flag = 0;
 int	file_out_flush = 0;
-char	file_out_mode[NI_MAXHOST] = "";
+char	file_out_mode[IPV6CALC_STRING_MAX] = "";
 FILE	*FILE_OUT;
 
 
@@ -103,9 +103,8 @@ int main(int argc,char *argv[]) {
 
 	/* options */
 	struct option longopts[IPV6CALC_MAXLONGOPTIONS];
-	char   shortopts[NI_MAXHOST] = "";
+	char   shortopts[IPV6CALC_STRING_MAX] = "";
 	int    longopts_maxentries = 0;
-	extern int optopt;
 
 	ipv6calc_quiet = 1; //default for ipv6loganon
 
@@ -237,6 +236,12 @@ int main(int argc,char *argv[]) {
 		feature_kg = 1;
 	};
 
+	/* check for standard anonymization support */
+	if ((libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_REGISTRY) == 1) \
+	    && (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV6_TO_REGISTRY) == 1)) {
+		feature_anon = 1;
+	};
+
 	/* do work depending on selection */
 	DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "command=0x%08x", command);
 
@@ -288,7 +293,7 @@ int main(int argc,char *argv[]) {
 		fflush(stdout);
 	};
 
-	libipv6calc_db_wrapper_cleanup();
+	libipv6calc_cleanup();
 
 	exit(EXIT_SUCCESS);
 };
@@ -470,7 +475,7 @@ static int anonymizetoken(char *resultstring, const size_t resultstring_length,
 
 	DEBUGSECTION_BEGIN(DEBUG_ipv6loganon_general)
 		if (inputtype != FORMAT_undefined) {
-			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatstrings); i++) {
+			for (i = 0; i < ipv6calc_formatstrings_entries; i++) {
 				if (inputtype == ipv6calc_formatstrings[i].number) {
 					DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "Found type: %s", ipv6calc_formatstrings[i].token);
 				};
@@ -562,8 +567,8 @@ static int anonymizetoken(char *resultstring, const size_t resultstring_length,
 		};
 
 		/* store key and value */
-		snprintf(cache_lru_key_token[cache_lru_last - 1], NI_MAXHOST, "%s", token);
-		snprintf(cache_lru_value[cache_lru_last - 1], NI_MAXHOST, "%s", resultstring);
+		snprintf(cache_lru_key_token[cache_lru_last - 1], IPV6CALC_STRING_MAX, "%s", token);
+		snprintf(cache_lru_value[cache_lru_last - 1], IPV6CALC_STRING_MAX, "%s", resultstring);
 		DEBUGPRINT_WA(DEBUG_ipv6loganon_cache, "LRU cache: fill line=%d key_token=%s value=%s", cache_lru_last - 1, cache_lru_key_token[cache_lru_last - 1], cache_lru_value[cache_lru_last - 1]);
 	};
 
