@@ -1,17 +1,17 @@
-#!/bin/bash
+#!/usr/bin/env bash
 #
 # Project    : ipv6calc
 # File       : test_ipv6loganon.sh
-# Version    : $Id: bd4751f8c708e3e9e7da8a1f122fe57bb91efcfc $
-# Copyright  : 2007-2017 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: 426ce12dc1ef1ced25ca3700575909fc7040c9a7 $
+# Copyright  : 2007-2021 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test program for "ipv6loganon"
 
-verbose=0
+verbose=false
 while getopts "Vh\?" opt; do
 	case $opt in
 	    V)
-		verbose=1
+		verbose=true
 		;;
 	    *)
 		echo "$0 [-V]"
@@ -49,8 +49,8 @@ testscenarios_standard() {
 # Address
 cat <<END | grep -v "^#"
 192.0.2.1 - - IPv4 address			=192.0.2.0 - - IPv4 address
-2001:0db8:0000:0000:81c0:0f3f:c807:1455 - - IPv6 address/privacy IID	=2001:db8::9:a929:4941:0:c - - IPv6 address/privacy IID
-3ffe:ffff::1 - - IPv6 address/6bone/static IID	=3ffe:ffff::9:a929:4291:c02d:5d15 - - IPv6 address/6bone/static IID
+2001:0db8:0000:0000:81c0:0f3f:c807:1455 - - IPv6 address/privacy IID	=2001:db8:0:9:a929:4941:0:c - - IPv6 address/privacy IID
+3ffe:ffff::1 - - IPv6 address/6bone/static IID	=3ffe:ffff:0:9:a929:4291:c02d:5d15 - - IPv6 address/6bone/static IID
 3FFE:1a05:510:200:0:5EFE:8CAD:8108 - - ISATAP	=3ffe:1a05:510:209:a929:5214:48ca:d81d - - ISATAP
 ff02::1:ff00:1234 - - Solicited Node		=ff02::1:ff00:0 - - Solicited Node
 3ffe::1:ff00:1234 - - Solicited Node		=3ffe::9:0:1:ff00:0 - - Solicited Node
@@ -61,15 +61,15 @@ ff02::1:ff00:1234 - - Solicited Node		=ff02::1:ff00:0 - - Solicited Node
 2002:50b5:7940::50b5:7940 - - 6to4 Microsoft	=2002:50b5:7900:9:a929:4291:850b:5794 - - 6to4 Microsoft
 fe80::210:a4ff:fe01:2345 - - link local EUI-48	=fe80::a909:4291:4021:a4c - - link local EUI-48
 fe80::210:a489:ab01:2345 - - link local EUI-64	=fe80::a909:4291:6021:a43 - - link local EUI-64
-3ffe:ffff::210:a4ff:fe01:2345 - - 6bone EUI-48	=3ffe:ffff::9:a929:4291:4021:a48 - - 6bone EUI-48
-3ffe:ffff::210:a489:ab01:2345 - - 6bone EUI-64	=3ffe:ffff::9:a929:4291:6021:a44 - - 6bone EUI-64
-3ffe:ffff::000:a4ff:fe01:2345 - - 6bone EUI-48 local	=3ffe:ffff::9:a929:4291:4000:a43 - - 6bone EUI-48 local
-3ffe:ffff::000:a489:ab01:2345 - - 6bone local	=3ffe:ffff::9:a929:4291:c02d:5d15 - - 6bone local
+3ffe:ffff::210:a4ff:fe01:2345 - - 6bone EUI-48	=3ffe:ffff:0:9:a929:4291:4021:a48 - - 6bone EUI-48
+3ffe:ffff::210:a489:ab01:2345 - - 6bone EUI-64	=3ffe:ffff:0:9:a929:4291:6021:a44 - - 6bone EUI-64
+3ffe:ffff::000:a4ff:fe01:2345 - - 6bone EUI-48 local	=3ffe:ffff:0:9:a929:4291:4000:a43 - - 6bone EUI-48 local
+3ffe:ffff::000:a489:ab01:2345 - - 6bone local	=3ffe:ffff:0:9:a929:4291:c02d:5d15 - - 6bone local
 fd00:1234:5678:9abc::1 - - ULUA local		=fd00:1234:5678:9a09:a929:4291:c02d:5d15 - - ULUA local
 fd00:1234:5678:9abc:210:a4ff:fe01:2345 - - ULUA EUI-48=fd00:1234:5678:9a09:a929:4291:4021:a48 - - ULUA EUI-48
 fd00:1234:5678:9abc:210:a489:ab01:2345 - - ULUA EUI-64=fd00:1234:5678:9a09:a929:4291:6021:a44 - - ULUA EUI-64
 3ffe:831f:ce49:7601:8000:efff:af4a:86BF - - Teredo 6bone=3ffe:831f:ce49:7601:8000:ffff:af4a:86ff - - Teredo 6bone
-2001:001a:392e:a450:2cd3:75e1:6098:8104 - - ORCHID=2001:19:a909:a909:a999:4843::e - - ORCHID
+2001:001a:392e:a450:2cd3:75e1:6098:8104 - - ORCHID=2001:19:a909:a909:a999:4843:0:e - - ORCHID
 END
 }
 
@@ -121,7 +121,7 @@ fe80::210:a4ff:fe01:2345 - - link local EUI-48/careful	=--anonymize-careful=fe80
 fe80::210:a489:ab01:2345 - - link local EUI-64/paranoid	=--anonymize-paranoid=fe80::a909:4291:6021:a43 - - link local EUI-64/paranoid
 fec0::1234:210:a4ff:fe01:2345 - - site local EUI-48/standard	=--anonymize-standard=fec0::1209:a929:4291:4021:a48 - - site local EUI-48/standard
 fec0::1234:210:a4ff:fe01:2345 - - site local EUI-48/careful	=--anonymize-careful=fec0::a909:a949:4291:4021:a46 - - site local EUI-48/careful
-fed0::1234:210:a489:ab01:2345 - - site local EUI-64/paranoid	=--anonymize-paranoid=fed0::9:a909:a969:4291:6021:a4c - - site local EUI-64/paranoid
+fed0::1234:210:a489:ab01:2345 - - site local EUI-64/paranoid	=--anonymize-paranoid=fed0:0:9:a909:a969:4291:6021:a4c - - site local EUI-64/paranoid
 fd00:1234:5678:9abc::1 - - ULUA local		=--anonymize-standard=fd00:1234:5678:9a09:a929:4291:c02d:5d15 - - ULUA local
 fd00:1234:5678:9abc:210:a4ff:fe01:2345 - - ULUA EUI-48/careful=--anonymize-careful=fd00:1234:5678:a909:a949:4291:4021:a46 - - ULUA EUI-48/careful
 fd00:1234:5678:9abc:210:a489:ab01:2345 - - ULUA EUI-64/paranoid=--anonymize-paranoid=fd00:1234:5609:a909:a969:4291:6021:a4c - - ULUA EUI-64/paranoid
@@ -145,41 +145,41 @@ if [ "$1" != "bulk" ]; then
 	testscenarios_standard | grep -v "^#" | while read line; do
 
 		# extract result
-		input="`echo $line | awk -F= '{ print $1 }' | sed 's/\W*$//g'`"
+		input="`echo $line | awk -F= '{ print $1 }' | sed 's/ *$//g'`"
 		result="`echo $line | awk -F= '{ print $2 }'`"
 		if [ -z "$result" -o -z "$input" ]; then
 			echo "Something is wrong in line '$line'"
 			exit 1
 		fi
-		[ "$verbose" = "1" ] && echo "IN     : $input"
-		[ "$verbose" = "1" ] && echo "CHECK  : $result"
+		$verbose && echo "IN     : $input"
+		$verbose && echo "CHECK  : $result"
 		# get result
 		output="`echo "$input" | ./ipv6loganon -q`"
 		retval=$?
-		[ "$verbose" = "1" ] && echo "OUT    : $output"
+		$verbose && echo "OUT    : $output"
 		if [ $retval -ne 0 ]; then
 			echo "Error executing 'ipv6loganon'!"
-			[ "$verbose" = "1" ] || echo "IN     : $input"
-			[ "$verbose" = "1" ] || echo "CHECK  : $result"
-			[ "$verbose" = "1" ] || echo "OUT    : $output"
+			$verbose || echo "IN     : $input"
+			$verbose || echo "CHECK  : $result"
+			$verbose || echo "OUT    : $output"
 			exit 1
 		fi
 		# Check result
 		if [ "$result" != "*" ]; then
 			if [ "$output" != "$result" ]; then
-				[ "$verbose" = "1" ] || echo "IN     : $input"
-				[ "$verbose" = "1" ] || echo "CHECK  : $result"
-				[ "$verbose" = "1" ] || echo "OUT    : $output"
+				$verbose || echo "IN     : $input"
+				$verbose || echo "CHECK  : $result"
+				$verbose || echo "OUT    : $output"
 				echo "RESULT : fail"
 				exit 1
 			fi
 		fi
-		[ "$verbose" = "1" ] && echo "RESULT : ok"
-		[ "$verbose" = "1" ] && echo
-		[ "$verbose" = "1" ] || echo -n "."
+		$verbose && echo "RESULT : ok"
+		$verbose && echo
+		$verbose || echo -n "."
 	done
 	retval=$?
-	[ "$verbose" = "1" ] || echo
+	$verbose || echo
 	echo "INFO  : $test successful"
 
 	if [ $retval -eq 0 ]; then
@@ -189,43 +189,43 @@ if [ "$1" != "bulk" ]; then
 		testscenarios_special | grep -v "^#" | while read line; do
 
 			# extract result
-			input="`echo $line | awk -F= '{ print $1 }' | sed 's/\W*$//g'`"
+			input="`echo $line | awk -F= '{ print $1 }' | sed 's/ *$//g'`"
 			options="`echo $line | awk -F= '{ print $2 }'`"
 			result="`echo $line | awk -F= '{ print $3 }'`"
 			if [ -z "$result" -o -z "$input" -o -z "$options" ]; then
 				echo "Something is wrong in line '$line'"
 				exit 1
 			fi
-			[ "$verbose" = "1" ] && echo "IN     : $input"
-			[ "$verbose" = "1" ] && echo "OPTIONS: $options"
-			[ "$verbose" = "1" ] && echo "CHECK  : $result"
+			$verbose && echo "IN     : $input"
+			$verbose && echo "OPTIONS: $options"
+			$verbose && echo "CHECK  : $result"
 			# get result
 			output="`echo "$input" | ./ipv6loganon -q $options`"
 			retval=$?
-			[ "$verbose" = "1" ] && echo "OUT    : $output"
+			$verbose && echo "OUT    : $output"
 			if [ $retval -ne 0 ]; then
 				echo "Error executing 'ipv6loganon'!"
-				[ "$verbose" = "1" ] || echo "IN     : $input"
-				[ "$verbose" = "1" ] || echo "CHECK  : $result"
-				[ "$verbose" = "1" ] || echo "OUT    : $output"
+				$verbose || echo "IN     : $input"
+				$verbose || echo "CHECK  : $result"
+				$verbose || echo "OUT    : $output"
 				exit 1
 			fi
 			# Check result
 			if [ "$result" != "*" ]; then
 				if [ "$output" != "$result" ]; then
-					[ "$verbose" = "1" ] || echo "IN     : $input"
-					[ "$verbose" = "1" ] || echo "CHECK  : $result"
-					[ "$verbose" = "1" ] || echo "OUT    : $output"
+					$verbose || echo "IN     : $input"
+					$verbose || echo "CHECK  : $result"
+					$verbose || echo "OUT    : $output"
 					echo "RESULT : fail"
 					exit 1
 				fi
 			fi
-			[ "$verbose" = "1" ] && echo "RESULT : ok"
-			[ "$verbose" = "1" ] && echo
-			[ "$verbose" = "1" ] || echo -n "."
+			$verbose && echo "RESULT : ok"
+			$verbose && echo
+			$verbose || echo -n "."
 		done
 		retval=$?
-		[ "$verbose" = "1" ] || echo
+		$verbose || echo
 		echo "INFO  : $test successful"
 	fi
 	echo 
@@ -359,8 +359,8 @@ run_loganon_options_tests() {
 		options="`echo $line | awk '{ for ( i = 1; i < NF; i++) printf "%s ", $i }'`"
 		input_result="`echo $line | awk '{ print $NF }'`"
 
-		[ "$verbose" = "1" ] && echo "DEBUG : options=$options"
-		[ "$verbose" = "1" ] && echo "DEBUG : input_result=$input_result"
+		$verbose && echo "DEBUG : options=$options"
+		$verbose && echo "DEBUG : input_result=$input_result"
 
 		input=${input_result/=*/}
 		result=${input_result/*=/}
@@ -374,17 +374,17 @@ run_loganon_options_tests() {
 		fi
 
 		if [ "$result" != "$result_real" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : result doesn't match on command: $command"
 			echo "ERROR : result is      : $result_real"
 			echo "ERROR : result expected: $result"
 			exit 1
 		else
-			[ "$verbose" = "1" ] && echo "INFO  : $command -> test ok"
+			$verbose && echo "INFO  : $command -> test ok"
 		fi
-		[ "$verbose" = "1" ] || echo -n "."
+		$verbose || echo -n "."
 	done || return 1
-	[ "$verbose" = "1" ] || echo
+	$verbose || echo
 	echo "INFO  : $test successful"
 }
 
@@ -417,7 +417,7 @@ run_loganon_options_kp_tests() {
 		fi
 
 		if [ "$result" != "$result_real" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : result doesn't match on command: $command"
 			echo "ERROR : result is      : $result_real"
 			echo "ERROR : result expected: $result"
