@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6logconv.c
- * Version    : $Id: f31f5be94eff12720c14bc53e4a9a22dbc1a1bab $
- * Copyright  : 2002-2019 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 1c0dd0452e5812570f95fb49f39af9ff056fda20 $
+ * Copyright  : 2002-2021 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile conversions
@@ -58,12 +58,12 @@ static void lineparser(const long int outputtype);
 /* LRU cache */
 
 #define CACHE_LRU_SIZE 200
-
+int cache_lru_limit;
 static int      cache_lru_max = 0;
 static int      cache_lru_last = 0;
-static char     cache_lru_key_token[CACHE_LRU_SIZE][NI_MAXHOST];
+static char     cache_lru_key_token[CACHE_LRU_SIZE][IPV6CALC_STRING_MAX];
 static long int cache_lru_key_outputtype[CACHE_LRU_SIZE];
-static char     cache_lru_value[CACHE_LRU_SIZE][NI_MAXHOST];
+static char     cache_lru_value[CACHE_LRU_SIZE][IPV6CALC_STRING_MAX];
 static long int cache_lru_statistics[CACHE_LRU_SIZE];
 
 int feature_reg = 0;
@@ -91,9 +91,8 @@ int main(int argc,char *argv[]) {
 
 	/* options */
 	struct option longopts[IPV6CALC_MAXLONGOPTIONS];
-	char   shortopts[NI_MAXHOST] = "";
+	char   shortopts[IPV6CALC_STRING_MAX] = "";
 	int    longopts_maxentries = 0;
-	extern int optopt;
 
 	/* check for UID */
 	if (getuid() == 0) {
@@ -222,7 +221,7 @@ int main(int argc,char *argv[]) {
 		ipv6logconv_printhelp();
 		exit(EXIT_FAILURE);
         } else if (command == CMD_printexamples) {
-		printhelp_output_dispatcher(outputtype);
+		printhelp_output_dispatcher(outputtype, inputtype);
 		exit(EXIT_FAILURE);
 	};
 
@@ -242,7 +241,7 @@ int main(int argc,char *argv[]) {
 	/* call lineparser */
 	lineparser(outputtype);
 
-	libipv6calc_db_wrapper_cleanup();
+	libipv6calc_cleanup();
 
 	exit(EXIT_SUCCESS);
 };
@@ -398,7 +397,7 @@ static int converttoken(char *resultstring, const size_t resultstring_length, co
 	uint32_t inputtype = FORMAT_undefined;
 	int retval = 1, i, registry;
 	uint32_t typeinfo_test;
-	char tempstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
 	ipv6calc_macaddr macaddr;
 
 	/* used structures */
@@ -466,7 +465,7 @@ static int converttoken(char *resultstring, const size_t resultstring_length, co
 
 	DEBUGSECTION_BEGIN(DEBUG_ipv6logconv_processing)
 		if (inputtype != FORMAT_undefined) {
-			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatstrings); i++) {
+			for (i = 0; i < ipv6calc_formatstrings_entries; i++) {
 				if (inputtype == ipv6calc_formatstrings[i].number) {
 					DEBUGPRINT_WA(DEBUG_ipv6logconv_processing, "Found type: %s", ipv6calc_formatstrings[i].token);
 				};
@@ -506,7 +505,7 @@ static int converttoken(char *resultstring, const size_t resultstring_length, co
 
 				/* scope of IPv6 address */
 				/* init retval */
-				for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++) {
+				for (i = 0; i < ipv6calc_ipv6addrtypestrings_entries; i++) {
 					if ( ipv6calc_ipv6addrtypestrings[i].number == IPV6_ADDR_ANY ) {
 						retval = i;
 						break;
@@ -515,7 +514,7 @@ static int converttoken(char *resultstring, const size_t resultstring_length, co
 				typeinfo_test = ipv6addr.typeinfo & (IPV6_NEW_ADDR_AGU | IPV6_ADDR_LINKLOCAL | IPV6_ADDR_SITELOCAL | IPV6_ADDR_MAPPED | IPV6_ADDR_COMPATv4 | IPV6_ADDR_ULUA);
 				if ( typeinfo_test != 0 ) {
 					/* get string */
-					for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++) {
+					for (i = 0; i < ipv6calc_ipv6addrtypestrings_entries; i++) {
 						if ( (typeinfo_test & ipv6calc_ipv6addrtypestrings[i].number) != 0 ) {
 							retval = i;
 							break;
@@ -527,7 +526,7 @@ static int converttoken(char *resultstring, const size_t resultstring_length, co
 
 				/* type of global IPv6 address */
 				/* init retval */
-				for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++) {
+				for (i = 0; i < ipv6calc_ipv6addrtypestrings_entries; i++) {
 					if ( ipv6calc_ipv6addrtypestrings[i].number == IPV6_ADDR_ANY ) {
 						retval = i;
 						break;
@@ -540,7 +539,7 @@ static int converttoken(char *resultstring, const size_t resultstring_length, co
 						snprintf(resultstring, resultstring_length, "%s", tempstring);
 					} else {
 						/* get string */
-						for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++) {
+						for (i = 0; i < ipv6calc_ipv6addrtypestrings_entries; i++) {
 							if ( (typeinfo_test & ipv6calc_ipv6addrtypestrings[i].number) != 0 ) {
 								retval = i;
 								break;
@@ -609,7 +608,7 @@ static int converttoken(char *resultstring, const size_t resultstring_length, co
 
 			ipv6addr_settype(&ipv6addr);
 
-			/* check whether address has a OUI ID */
+			/* check whether address has an OUI ID */
 			if ( (( ipv6addr.typeinfo & (IPV6_ADDR_LINKLOCAL | IPV6_ADDR_SITELOCAL | IPV6_NEW_ADDR_AGU | IPV6_NEW_ADDR_6BONE | IPV6_NEW_ADDR_6TO4 | IPV6_ADDR_ULUA)) == 0) && ((ipv6addr.typeinfo & (IPV6_NEW_ADDR_TEREDO)) == 0) )  {
 				if (flag_skipunknown != 0) {
 					return (1);
@@ -716,9 +715,9 @@ static int converttoken(char *resultstring, const size_t resultstring_length, co
 		};
 
 		/* store key and value */
-		snprintf(cache_lru_key_token[cache_lru_last - 1], NI_MAXHOST - 1, "%s", token);
+		snprintf(cache_lru_key_token[cache_lru_last - 1], IPV6CALC_STRING_MAX - 1, "%s", token);
 		cache_lru_key_outputtype[cache_lru_last - 1] = outputtype;
-		snprintf(cache_lru_value[cache_lru_last - 1], NI_MAXHOST - 1, "%s", resultstring);
+		snprintf(cache_lru_value[cache_lru_last - 1], IPV6CALC_STRING_MAX - 1, "%s", resultstring);
 		DEBUGPRINT_WA(DEBUG_ipv6logconv_processing, "LRU cache: fill line=%d key_token=%s key_outputtype=%lx value=%s", cache_lru_last - 1, cache_lru_key_token[cache_lru_last - 1], cache_lru_key_outputtype[cache_lru_last - 1], cache_lru_value[cache_lru_last - 1]);
 	};
 
