@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6logconvoptions.h
- * Version    : $Id: ipv6logconvoptions.h,v 1.5 2007/01/30 15:46:45 peter Exp $
+ * Version    : $Id: 1c5b331c3db83c58e71f86efc8b742381e407e28 $
  * Copyright  : 2002-2007 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -20,25 +20,24 @@
 /* Options */
 
 /* define short options */
-static char *ipv6logconv_shortopts = "vnqh?d:c:";
+static char *ipv6logconv_shortopts = "vfh?nc:";
 
 /* define long options */
 static struct option ipv6logconv_longopts[] = {
-	{"version", 0, 0, (int) 'v'},
-	{"debug", 1, 0, (int) 'd'},
-	{"quiet", 0, 0, (int) 'q'},
-	{"nocache", 0, 0, (int) 'n'},
-	{"cachelimit", 0, 0, (int) 'c'},
+	{"version", 0, NULL, (int) 'v' },
+	{"flush"  , 0, NULL, (int) 'f' },
 
 	/* help options */
-	{"help", 0, 0, (int) 'h'},
+	{"help"           , 0, NULL, (int) 'h'},
 	{"examples"     , 0, 0, CMD_printexamples },
 	{"printexamples", 0, 0, CMD_printexamples },
 
+	/* cache options */
+	{"nocache", 0, 0, (int) 'n'},
+	{"cachelimit", 0, 0, (int) 'c'},
+
 	/* options */
 	{ "out"       , 1, 0, CMD_outputtype },
-
-	{NULL, 0, 0, 0}
 };                
 
 #endif
