@@ -2,7 +2,7 @@
 #
 # Project    : ipv6calc/logstats
 # File       : example_ipv6logstats.sh
-# Version    : $Id: 2764fee1b8880100bf3531b08355ef82f0c517c5 $
+# Version    : $Id: 7babf149c6679c1e7c18a73d27123787061ae4d7 $
 # Copyright  : 2003-2014 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Example program for "ipv6logstats"
@@ -53,5 +53,5 @@ find $dir -name '*-log.*' -type f | while read file; do
 	fi
 done | sort -u | while read yearmonth; do
 	# don't count mon and check_http (from Nagios)
-	cat_file `find $dir -name "*-log.$yearmonth*" -type f` | egrep -v "(mon.d/http.monitor|check_http)" | $bin -c -q -n -p "$yearmonth" || exit 1
+	cat_file `find $dir -name "*-log.$yearmonth*" -type f` | grep -Ev "(mon.d/http.monitor|check_http)" | $bin -c -q -n -p "$yearmonth" || exit 1
 done
