@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc/ipv6logstats
  * File       : ipv6logstats.c
- * Version    : $Id: c394b528ed9bb4e7a048ad439d0e0bb9f4d87549 $
- * Copyright  : 2003-2019 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 65e89a4b30f28413246245000c6d4a2a0dad97f8 $
+ * Copyright  : 2003-2021 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile statistics
@@ -32,10 +32,8 @@
 #include "libifinet6.h"
 
 #include "../databases/lib/libipv6calc_db_wrapper.h"
-#include "../databases/lib/libipv6calc_db_wrapper_GeoIP.h"
 #include "../databases/lib/libipv6calc_db_wrapper_GeoIP2.h"
 #include "../databases/lib/libipv6calc_db_wrapper_IP2Location.h"
-#include "../databases/lib/libipv6calc_db_wrapper_DBIP.h"
 #include "../databases/lib/libipv6calc_db_wrapper_DBIP2.h"
 #include "../databases/lib/libipv6calc_db_wrapper_External.h"
 #include "../databases/lib/libipv6calc_db_wrapper_BuiltIn.h"
@@ -50,9 +48,9 @@ static int opt_column_numbers = 0;
 static int opt_noheader = 0;
 static int opt_onlyheader = 0;
 static int opt_printdirection = 0; /* rows */
-static char opt_token[NI_MAXHOST] = "";
+static char opt_token[IPV6CALC_STRING_MAX] = "";
 
-char    file_out[NI_MAXHOST] = "";
+char    file_out[IPV6CALC_STRING_MAX] = "";
 int     file_out_flag = 0;
 FILE    *FILE_OUT;
 
@@ -142,9 +140,8 @@ int main(int argc,char *argv[]) {
 
 	/* options */
 	struct option longopts[IPV6CALC_MAXLONGOPTIONS];
-	char   shortopts[NI_MAXHOST] = "";
+	char   shortopts[IPV6CALC_STRING_MAX] = "";
 	int    longopts_maxentries = 0;
-	extern int optopt;
 
 	/* check for UID */
 	if (getuid() == 0) {
@@ -308,7 +305,7 @@ int main(int argc,char *argv[]) {
 	/* call lineparser */
 	lineparser();
 
-	libipv6calc_db_wrapper_cleanup();
+	libipv6calc_cleanup();
 
 	exit(EXIT_SUCCESS);
 };
@@ -578,25 +575,25 @@ static void lineparser(void) {
 
 					if (stat_registry_base > 0) {
 						switch (registry) {
-							case IPV4_ADDR_REGISTRY_IANA:
+							case REGISTRY_IANA:
 								stat_inc(stat_registry_base + REGISTRY_IANA);
 								break;
-							case IPV4_ADDR_REGISTRY_APNIC:
+							case REGISTRY_APNIC:
 								stat_inc(stat_registry_base + REGISTRY_APNIC);
 								break;
-							case IPV4_ADDR_REGISTRY_ARIN:
+							case REGISTRY_ARIN:
 								stat_inc(stat_registry_base + REGISTRY_ARIN);
 								break;
-							case IPV4_ADDR_REGISTRY_RIPENCC:
+							case REGISTRY_RIPENCC:
 								stat_inc(stat_registry_base + REGISTRY_RIPENCC);
 								break;
-							case IPV4_ADDR_REGISTRY_LACNIC:
+							case REGISTRY_LACNIC:
 								stat_inc(stat_registry_base + REGISTRY_LACNIC);
 								break;
-							case IPV4_ADDR_REGISTRY_AFRINIC:
+							case REGISTRY_AFRINIC:
 								stat_inc(stat_registry_base + REGISTRY_AFRINIC);
 								break;
-							case IPV4_ADDR_REGISTRY_RESERVED:
+							case REGISTRY_RESERVED:
 								stat_inc(stat_registry_base + REGISTRY_RESERVED);
 								break;
 							default:
@@ -630,28 +627,28 @@ static void lineparser(void) {
 					registry = libipv6addr_registry_num_by_addr(&ipv6addr);
 
 					switch (registry) {
-						case IPV6_ADDR_REGISTRY_6BONE:
+						case REGISTRY_6BONE:
 							stat_inc(STATS_IPV6_6BONE);
 							break;
-						case IPV6_ADDR_REGISTRY_IANA:
+						case REGISTRY_IANA:
 							stat_inc(STATS_IPV6_IANA);
 							break;
-						case IPV6_ADDR_REGISTRY_APNIC:
+						case REGISTRY_APNIC:
 							stat_inc(STATS_IPV6_APNIC);
 							break;
-						case IPV6_ADDR_REGISTRY_ARIN:
+						case REGISTRY_ARIN:
 							stat_inc(STATS_IPV6_ARIN);
 							break;
-						case IPV6_ADDR_REGISTRY_RIPENCC:
+						case REGISTRY_RIPENCC:
 							stat_inc(STATS_IPV6_RIPENCC);
 							break;
-						case IPV6_ADDR_REGISTRY_LACNIC:
+						case REGISTRY_LACNIC:
 							stat_inc(STATS_IPV6_LACNIC);
 							break;
-						case IPV6_ADDR_REGISTRY_AFRINIC:
+						case REGISTRY_AFRINIC:
 							stat_inc(STATS_IPV6_AFRINIC);
 							break;
-						case IPV6_ADDR_REGISTRY_RESERVED:
+						case REGISTRY_RESERVED:
 							stat_inc(STATS_IPV6_RESERVED);
 							break;
 						default:
@@ -694,25 +691,25 @@ static void lineparser(void) {
 				registry = libipv4addr_registry_num_by_addr(&ipv4addr);
 
 				switch (registry) {
-					case IPV4_ADDR_REGISTRY_IANA:
+					case REGISTRY_IANA:
 						stat_inc(STATS_IPV4_IANA);
 						break;
-					case IPV4_ADDR_REGISTRY_APNIC:
+					case REGISTRY_APNIC:
 						stat_inc(STATS_IPV4_APNIC);
 						break;
-					case IPV4_ADDR_REGISTRY_ARIN:
+					case REGISTRY_ARIN:
 						stat_inc(STATS_IPV4_ARIN);
 						break;
-					case IPV4_ADDR_REGISTRY_RIPENCC:
+					case REGISTRY_RIPENCC:
 						stat_inc(STATS_IPV4_RIPENCC);
 						break;
-					case IPV4_ADDR_REGISTRY_LACNIC:
+					case REGISTRY_LACNIC:
 						stat_inc(STATS_IPV4_LACNIC);
 						break;
-					case IPV4_ADDR_REGISTRY_AFRINIC:
+					case REGISTRY_AFRINIC:
 						stat_inc(STATS_IPV4_AFRINIC);
 						break;
-					case IPV4_ADDR_REGISTRY_RESERVED:
+					case REGISTRY_RESERVED:
 						stat_inc(STATS_IPV4_RESERVED);
 						break;
 					default:
