@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calc_inttypes.h
- * Version    : $Id: e22d7d8b2a44d96927e6bd9495bf93d738e4ce58 $
- * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 1e1de3c96fcbbfff597a3fad0b40436ba6cfa683 $
+ * Copyright  : 2002-2021 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Common header file to define inttypes like uint8_t and other basics
@@ -24,10 +24,17 @@
 
 
 /* max string length */
-#define NI_MAXHOST      		1024
+#define IPV6CALC_STRING_MAX		1024
 #define IPV6CALC_ADDR_STRING_MAX	256
 #define IPV6CALC_SCOPEID_STRING_MAX	64
 #define IPV6CALC_COUNTRYCODE_STRING_MAX	16
 
 
+#include <limits.h>
+
+#ifndef PATH_MAX
+#define PATH_MAX			1024 // fallback
+#warning "system include files missing definition of PATH_MAX -> use fallback"
+#endif
+
 #endif // _ipv6calc_inttypes_h
