@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calccommands.h
- * Version    : $Id: 0c21603ddce56cfcc3de830f577bdf396197d7fd $
+ * Version    : $Id: 1c13437c8bbbe2f721df70a077ccd32f38a406b6 $
  * Copyright  : 2002-2019 by Peter Bieringer <pb (at) bieringer.de>
  * License    : GPLv2
  *
@@ -53,15 +53,20 @@
 #define CMD_showinfo			0x0010010
 #define CMD_showinfotypes		0x0010020
 
-/* database options (old) */
-#define DB_ip2location_ipv4		0x0020010
-#define DB_ip2location_ipv6		0x0020020
-#define DB_ip2location_ipv4_default	0x0020030
-#define DB_ip2location_ipv6_default	0x0020040
-#define DB_geoip_ipv4			0x0021010
-#define DB_geoip_ipv6			0x0021020
-#define DB_geoip_ipv4_default		0x0002103
-#define DB_geoip_ipv6_default		0x0002104
+/* database options (old), EOS since 3.0.0 */
+#define DB_EOS_ip2location_ipv4		0x0020010
+#define DB_EOS_ip2location_ipv6		0x0020020
+#define DB_EOS_ip2location_ipv4_default	0x0020030
+#define DB_EOS_ip2location_ipv6_default	0x0020040
+
+// EOS since 3.0.0
+#define DB_EOS_geoip_disable		0x0021000
+#define DB_EOS_geoip_ipv4			0x0021010
+#define DB_EOS_geoip_ipv6			0x0021020
+#define DB_EOS_geoip_ipv4_default		0x0021030
+#define DB_EOS_geoip_ipv6_default		0x0021040
+#define DB_EOS_geoip_dir			0x0021050
+#define DB_EOS_geoip_lib			0x0021060
 
 /* database options (new) */
 #define DB_ip2location_disable		0x0020000
@@ -72,14 +77,11 @@
 #define DB_ip2location_only_type	0x0020120
 #define DB_ip2location_allow_softlinks	0x0020130
 
-#define DB_geoip_disable		0x0021000
-#define DB_geoip_dir			0x0021050
-#define DB_geoip_lib			0x0021060
-
-#define DB_dbip_disable			0x0022000
-#define DB_dbip_dir			0x0022050
-#define DB_dbip_comm_to_free_switch_min_delta_months		0x0022110
-#define DB_dbip_only_type		0x0022120
+// EOS since 3.0.0
+#define DB_EOS_dbip_disable			0x0022000
+#define DB_EOS_dbip_dir			0x0022050
+#define DB_EOS_dbip_comm_to_free_switch_min_delta_months		0x0022110
+#define DB_EOS_dbip_only_type		0x0022120
 
 #define DB_external_disable		0x0023000
 #define DB_external_dir			0x0023050
