@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calcoptions.c
- * Version    : $Id: ea7f547e271c968576c3218ffa8cecb522d7b417 $
+ * Version    : $Id: 5bdb1c99653c66beede3e9d5d4e50d835a1ebe7c $
  * Copyright  : 2013-2019 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -18,7 +18,7 @@
 #include "ipv6calcoptions.h"
 #include "ipv6calcoptions_common.h"
 
-#include "databases/lib/libipv6calc_db_wrapper.h"
+#include "libipv6calc_db_wrapper.h"
 
 extern long int ipv6calc_debug; // ipv6calc_debug usage ok
 int ipv6calc_quiet = 0;
@@ -74,7 +74,7 @@ void ipv6calc_debug_from_env(void) {
 void ipv6calc_options_add(char *shortopts_p, const int shortopts_maxlen, struct option longopts[], int *maxentries_p, const char *shortopts_custom, const struct option longopts_custom[], const int longopts_custom_entries) {
 	int i, l;
 	unsigned int j, k;
-	char tempstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
 
 	DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Called: longopts_custom_entries=%d shortopts=%s", longopts_custom_entries, shortopts_p);
 
@@ -155,21 +155,11 @@ void ipv6calc_options_add_common_basic(char *shortopts_p, const int shortopts_ma
 	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_ip2location, ipv6calc_longopts_ip2location, MAXENTRIES_ARRAY(ipv6calc_longopts_ip2location));
 #endif
 
-#ifdef SUPPORT_GEOIP
-	DEBUGPRINT_NA(DEBUG_ipv6calcoptions, "SUPPORT_GEOIP");
-	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_geoip, ipv6calc_longopts_geoip, MAXENTRIES_ARRAY(ipv6calc_longopts_geoip));
-#endif
-
 #ifdef SUPPORT_GEOIP2
 	DEBUGPRINT_NA(DEBUG_ipv6calcoptions, "SUPPORT_GEOIP2");
 	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_geoip2, ipv6calc_longopts_geoip2, MAXENTRIES_ARRAY(ipv6calc_longopts_geoip2));
 #endif
 
-#ifdef SUPPORT_DBIP
-	DEBUGPRINT_NA(DEBUG_ipv6calcoptions, "SUPPORT_DBIP");
-	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_dbip, ipv6calc_longopts_dbip, MAXENTRIES_ARRAY(ipv6calc_longopts_dbip));
-#endif
-
 #ifdef SUPPORT_DBIP2
 	DEBUGPRINT_NA(DEBUG_ipv6calcoptions, "SUPPORT_DBIP2");
 	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_dbip2, ipv6calc_longopts_dbip2, MAXENTRIES_ARRAY(ipv6calc_longopts_dbip2));
@@ -185,7 +175,7 @@ void ipv6calc_options_add_common_basic(char *shortopts_p, const int shortopts_ma
 	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_builtin, ipv6calc_longopts_builtin, MAXENTRIES_ARRAY(ipv6calc_longopts_builtin));
 #endif
 
-#if defined SUPPORT_EXTERNAL || defined SUPPORT_DBIP || defined SUPPORT_GEOIP || SUPPORT_IP2LOCATION || defined SUPPORT_DBIP2 || defined SUPPORT_GEOIP2
+#if defined SUPPORT_EXTERNAL || SUPPORT_IP2LOCATION || defined SUPPORT_DBIP2 || defined SUPPORT_GEOIP2
 	DEBUGPRINT_NA(DEBUG_ipv6calcoptions, "DB_COMMON");
 	ipv6calc_options_add(shortopts_p, shortopts_maxlen, longopts, maxentries_p, ipv6calc_shortopts_db_common, ipv6calc_longopts_db_common, MAXENTRIES_ARRAY(ipv6calc_longopts_db_common));
 #endif
@@ -387,7 +377,7 @@ int ipv6calcoptions_common_anon(const int opt, const char *optarg, const struct
 			break;
 
 		case CMD_ANON_METHOD_OPTION:
-			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_anon_methods); i++) {
+			for (i = 0; i < ipv6calc_anon_methods_entries; i++) {
 				if (strcmp(ipv6calc_anon_methods[i].name, optarg) == 0) {
 					ipv6calc_anon_set_p->method = ipv6calc_anon_methods[i].method;
 					snprintf(ipv6calc_anon_set_p->name, sizeof(ipv6calc_anon_set_p->name), "%s", "custom");
@@ -395,7 +385,7 @@ int ipv6calcoptions_common_anon(const int opt, const char *optarg, const struct
 				};
 			};
 
-			if (i == MAXENTRIES_ARRAY(ipv6calc_anon_methods)) {
+			if (i == ipv6calc_anon_methods_entries) {
 				fprintf(stderr, "anonymization method not supported: %s\n", optarg);
 				exit(EXIT_FAILURE);
 			};
@@ -433,7 +423,7 @@ const char *ipv6calcoption_name(const int opt, const struct option longopts[]) {
 void ipv6calc_common_options_from_env(const struct option longopts[], s_ipv6calc_anon_set *ipv6calc_anon_set_p) {
 	int i, result;
 	unsigned int s;
-	char tempstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
 	char *environment_value;
 
 	i = 0;
