@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : libeui64.c
- * Version    : $Id: 6c5c3094e52f89a9cf78d5043464012820e1f99b $
- * Copyright  : 2001-2018 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: fe0536bb99d61fec67b019cd0bc993f1678be147 $
+ * Copyright  : 2001-2019 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Function library EUI-64 identifier handling
@@ -64,7 +64,7 @@ int create_eui64_from_mac(ipv6calc_ipv6addr *ipv6addrp, ipv6calc_macaddr *macadd
  * ret: ==0: ok, !=0: error
  */
 int libeui64_eui64addrstruct_to_string(const ipv6calc_eui64addr *eui64addr_p, char *resultstring, const size_t resultstring_length, const uint32_t formatoptions) {
-	char tempstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
 
 	/* address */
 	snprintf(tempstring, sizeof(tempstring), "%02x:%02x:%02x:%02x:%02x:%02x:%02x:%02x", \
@@ -230,7 +230,7 @@ void libeui64_anonymize(ipv6calc_eui64addr *eui64addrp, const s_ipv6calc_anon_se
 				if ((eui64addrp->addr[3] == 0xff) && (eui64addrp->addr[4] == 0xfe)) {
 					// expanded EUI-48
 					mask = 40; // 24 + 16 bits
-					DEBUGPRINT_WA(DEBUG_libeui64, "EUI-64 is a expanded EUI-48, change mask: %d", mask);
+					DEBUGPRINT_WA(DEBUG_libeui64, "EUI-64 is an expanded EUI-48, change mask: %d", mask);
 				} else {
 					mask = 24;
 				};
@@ -239,6 +239,10 @@ void libeui64_anonymize(ipv6calc_eui64addr *eui64addrp, const s_ipv6calc_anon_se
 					// OUI-36/IAB
 					mask += 12; // increase by 12 bits
 					DEBUGPRINT_WA(DEBUG_libeui64, "EUI-64 contains OUI-36/IAB, change mask: %d", mask);
+				} else if (libieee_check_oui28(EUI64_00_23(eui64addrp->addr)) == 1) {
+					// OUI-28
+					mask += 4; // increase by 4 bits
+					DEBUGPRINT_WA(DEBUG_libeui64, "EUI-64 contains OUI-28, change mask: %d", mask);
 				};
 
 				DEBUGPRINT_WA(DEBUG_libeui64, "EUI-64 is a global one, source of mask: automagic: %d", mask);
@@ -292,4 +296,3 @@ void libeui64_anonymize(ipv6calc_eui64addr *eui64addrp, const s_ipv6calc_anon_se
 
 	return;
 };
-
