@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : libieee.c
- * Version    : $Id: d64626b095f64473a2801ecbfe7b74133981398b $
+ * Version    : $Id: 0d1212734228f7aeb3dbc7b8e1d4f47215f0fb63 $
  * Copyright  : 2002-2022 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -324,6 +324,61 @@ static const s_ieee_mapping ieee_mapping[] = {
 	{ 0x6C9308,	IEEE_OUI28, 0x011a },
 	{ 0x988FE0,	IEEE_OUI28, 0x011b },
 	{ 0xDC3643,	IEEE_OUI28, 0x011c },
+
+	// OUI28 (2022-07-30)
+	{ 0x0C7FED,	IEEE_OUI28, 0x011d },
+	{ 0x18A59C,	IEEE_OUI28, 0x011e },
+	{ 0x18C3F4,	IEEE_OUI28, 0x011f },
+	{ 0x1C5974,	IEEE_OUI28, 0x0120 },
+	{ 0x2C691D,	IEEE_OUI28, 0x0121 },
+	{ 0x303D51,	IEEE_OUI28, 0x0122 },
+	{ 0x381F26,	IEEE_OUI28, 0x0123 },
+	{ 0x5847CA,	IEEE_OUI28, 0x0124 },
+	{ 0x6C1524,	IEEE_OUI28, 0x0125 },
+	{ 0x7050E7,	IEEE_OUI28, 0x0126 },
+	{ 0x8002F4,	IEEE_OUI28, 0x0127 },
+	{ 0x883CC5,	IEEE_OUI28, 0x0128 },
+	{ 0x8C5109,	IEEE_OUI28, 0x0129 },
+	{ 0xC48372,	IEEE_OUI28, 0x012a },
+	{ 0xC49894,	IEEE_OUI28, 0x012b },
+	{ 0xC4A10E,	IEEE_OUI28, 0x012c },
+	{ 0xD09686,	IEEE_OUI28, 0x012d },
+	{ 0xD42000,	IEEE_OUI28, 0x012e },
+	{ 0xD4BABA,	IEEE_OUI28, 0x012f },
+	{ 0xFC6179,	IEEE_OUI28, 0x0130 },
+
+	// OUI28 (2022-12-04)
+	{ 0x0CCC47,	IEEE_OUI28, 0x0131 },
+	{ 0x4C74A7,	IEEE_OUI28, 0x0132 },
+	{ 0x705A6F,	IEEE_OUI28, 0x0133 },
+	{ 0x7C45F9,	IEEE_OUI28, 0x0134 },
+	{ 0x84B386,	IEEE_OUI28, 0x0135 },
+	{ 0x8C5DB2,	IEEE_OUI28, 0x0136 },
+	{ 0xC0EAC3,	IEEE_OUI28, 0x0137 },
+	{ 0xC4A559,	IEEE_OUI28, 0x0138 },
+	{ 0xD46137,	IEEE_OUI28, 0x0139 },
+	{ 0xE0382D,	IEEE_OUI28, 0x013a },
+	{ 0xF0221D,	IEEE_OUI28, 0x013b },
+
+	// OUI28 (2023-06-08)
+	{ 0x50482C,	IEEE_OUI28, 0x013c },
+	{ 0x54083B,	IEEE_OUI28, 0x013d },
+	{ 0x5491AF,	IEEE_OUI28, 0x013e },
+	{ 0x58C41E,	IEEE_OUI28, 0x013f },
+	{ 0x5C6AEC,	IEEE_OUI28, 0x0140 },
+	{ 0x68DA73,	IEEE_OUI28, 0x0141 },
+	{ 0x6C2ADF,	IEEE_OUI28, 0x0142 },
+	{ 0x700692,	IEEE_OUI28, 0x0143 },
+	{ 0x88A6EF,	IEEE_OUI28, 0x0144 },
+	{ 0x90F421,	IEEE_OUI28, 0x0145 },
+	{ 0xB0FF72,	IEEE_OUI28, 0x0146 },
+	{ 0xB44D43,	IEEE_OUI28, 0x0147 },
+	{ 0xBC3198,	IEEE_OUI28, 0x0148 },
+	{ 0xC86BBC,	IEEE_OUI28, 0x0149 },
+	{ 0xD015BB,	IEEE_OUI28, 0x014a },
+	{ 0xD016F0,	IEEE_OUI28, 0x014b },
+	{ 0xD09395,	IEEE_OUI28, 0x014c },
+	{ 0xE03C1C,	IEEE_OUI28, 0x014d },
 };
 
 
