@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv4addr.c
- * Version    : $Id: b2da5641d8dc6997a5ba05c1bd20888c3ea4e09c $
- * Copyright  : 2002-2019 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
+ * Version    : $Id: 95ff361371668cdc094acac0b1e9c2f46f77625d $
+ * Copyright  : 2002-2021 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  * License    : GNU GPL v2
  *
  * Information:
@@ -13,6 +13,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
+#include <regex.h>
 
 #include "config.h"
 #include "libipv4addr.h"
@@ -20,7 +21,39 @@
 #include "libipv6calc.h"
 #include "libipv6calcdebug.h"
 
-#include "../databases/lib/libipv6calc_db_wrapper.h"
+#include "libipv6calc_db_wrapper.h"
+
+/* regex cache */
+#define LIBIPV4ADDR_REGEX_CACHE_MAX	8
+#define LIBIPV4ADDR_REGEX_IPV4_OCTAL	0
+
+static regex_t libipv4addr_regex_cache_entry[LIBIPV4ADDR_REGEX_CACHE_MAX];
+static int     libipv4addr_regex_cache_valid[LIBIPV4ADDR_REGEX_CACHE_MAX];
+
+
+/* text representation */
+const s_type ipv6calc_ipv4addrtypestrings[] = {
+	{ IPV4_ADDR_ANY			, "any" },
+	{ IPV4_ADDR_UNICAST		, "unicast" },
+	{ IPV4_ADDR_MULTICAST		, "multicast" },
+	{ IPV4_ADDR_ANYCAST		, "anycast" },
+	{ IPV4_ADDR_BROADCAST		, "broadcast" },
+	{ IPV4_ADDR_LOOPBACK		, "loopback" },
+	{ IPV4_ADDR_UNSPECIFIED		, "unspecified" },
+	{ IPV4_ADDR_UNKNOWN		, "unknown" },
+	{ IPV4_ADDR_RESERVED		, "reserved" },
+	{ IPV4_ADDR_ZEROCONF		, "zeroconf" },
+	{ IPV4_ADDR_SITELOCAL		, "site-local" },
+	{ IPV4_ADDR_ANONYMIZED		, "anonymized" },
+	{ IPV4_ADDR_ANONYMIZED_GEONAMEID, "anonymized-geonameid" },
+	{ IPV4_ADDR_GLOBAL		, "global" },
+	{ IPV4_ADDR_6TO4RELAY		, "6to4relay" },
+	{ IPV4_ADDR_LISP	 	, "lisp" },
+	{ IPV4_ADDR_LISP_PETR		, "lisp-proxyegresstunnelrouter-anycast" },
+	{ IPV4_ADDR_LISP_MAP_RESOLVER	, "lisp-mapresolver-anycast" },
+};
+
+const int ipv6calc_ipv4addrtypestrings_entries = MAXENTRIES_ARRAY(ipv6calc_ipv4addrtypestrings);
 
 
 /*
@@ -353,7 +386,7 @@ uint32_t ipv4addr_gettype(const ipv6calc_ipv4addr *ipv4addrp) {
 				goto END_ipv4addr_gettype;
 			};
 		} else {
-				DEBUGPRINT_NA(DEBUG_libipv4addr, "Address is not an detected anonymized one");
+				DEBUGPRINT_NA(DEBUG_libipv4addr, "Address is not a detected anonymized one");
 		};
 	};
 
@@ -436,116 +469,126 @@ END_ipv4addr_gettype:
  * ret: ==0: ok, !=0: error
  */
 int addr_to_ipv4addrstruct(const char *addrstring, char *resultstring, const size_t resultstring_length, ipv6calc_ipv4addr *ipv4addrp) {
-	int retval = 1, result, i;
-	unsigned int cpoints = 0, cdigits = 0;
-	char *addronlystring, *cp;
-	int expecteditems = 0;
-	int compat[4];
-	char tempstring[NI_MAXHOST], *cptr, **ptrptr;
+	int in_prefix_len = 0, digit = 0;
+	unsigned int compat[5], i;
 	uint32_t typeinfo;
+	const char *p;
+	int revalue;
 
-	ptrptr = &cptr;
-
-	resultstring[0] = '\0'; /* clear result string */
+	if (resultstring_length > 0)
+		resultstring[0] = '\0'; /* clear result string */
 
 	DEBUGPRINT_WA(DEBUG_libipv4addr, "Got input '%s'",  addrstring);
 
-	if ((strlen(addrstring) < 7) || (strlen(addrstring) > 18)) {
-		/* min: 0.0.0.0 */
-		/* max: 123.123.123.123/32 */
-		snprintf(resultstring, resultstring_length, "Error in given dot notated IPv4 address, has not 7 to 18 chars!");
+	if (*addrstring == '\0') {
+		snprintf(resultstring, resultstring_length, "Error in given dot notated IPv4 address: empty string!");
 		return (1);
+	}
+
+	memset(compat, 0, sizeof(compat));
+
+	// catch octal notation
+	if (libipv4addr_regex_cache_valid[LIBIPV4ADDR_REGEX_IPV4_OCTAL] == 0) {
+		// compile and store in cache
+		revalue = regcomp(&libipv4addr_regex_cache_entry[LIBIPV4ADDR_REGEX_IPV4_OCTAL], "^0[0-7]{3}\\.0[0-7]{3}\\.0[0-7]{3}\\.0[0-7]{3}(/[0-9]{1,2})?$", REG_EXTENDED);
+		if (revalue != 0) {
+			fprintf(stderr, "FATAL - regular expression compilation issue");
+			exit(1);
+		};
+
+		libipv4addr_regex_cache_valid[LIBIPV4ADDR_REGEX_IPV4_OCTAL] = 1;
 	};
 
-	if (strlen(addrstring) >= sizeof(tempstring)) {
-		ERRORPRINT_WA("Input too long: %s", addrstring);
-		return (1);
+	if (regexec(&libipv4addr_regex_cache_entry[LIBIPV4ADDR_REGEX_IPV4_OCTAL], addrstring, 0 , NULL, 0) == 0) {
+		if (sscanf(addrstring, "0%3o.0%3o.0%3o.0%3o/%2d", &compat[0], &compat[1], &compat[2], &compat[3], &compat[4]) == 5) {
+			// IPv4 address in octal format separated by . with prefix length
+			in_prefix_len = 1;
+			goto END_addr_to_ipv4addrstruct;
+		} else if (sscanf(addrstring, "0%3o.0%3o.0%3o.0%3o", &compat[0], &compat[1], &compat[2], &compat[3]) == 4) {
+			// IPv4 address in octal format separated by .
+			goto END_addr_to_ipv4addrstruct;
+		};
 	};
 
-	snprintf(tempstring, sizeof(tempstring), "%s", addrstring);
-	
+	// standard but potentially shortened notation
+	for (p = addrstring, i = 0; *p && i < (in_prefix_len ? 5 : 4); p++)
+	{
+		if (*p >= '0' && *p <= '9') {
+			digit = 1;
+			if (in_prefix_len && p[0] == '0' && p[1] && compat[i] == 0) {
+				snprintf(resultstring, resultstring_length, "Error in given IPv4 address, '%s' is not valid (CIDR prefix length cannot start with zero)!",
+					 addrstring);
+				return (1);
+			}
+			compat[i] = compat[i] * 10 + (*p - '0');
+			if (compat[i] > (in_prefix_len ? 32 : 255)) {
+				snprintf(resultstring, resultstring_length, "Error in given IPv4 address, '%s' is not valid (%d on position %d)!",
+					 addrstring, compat[i], (int)(p - addrstring + 1));
+				return (1);
+			}
+		} else if (*p == '.' && !in_prefix_len && digit) {
+			digit = 0;
+			i++;
+		} else if (*p == '/' && !in_prefix_len && p != addrstring) {
+			digit = 0;
+			in_prefix_len = 1;
+			i = 4;
+		} else {
+			snprintf(resultstring, resultstring_length, "Error in given IPv4 address, '%s' is not valid (illegal char at %d)!",
+				 addrstring, (int)(p - addrstring + 1));
+			return (1);
+		}
+	}
+	if (p[-1] == '/') {
+		snprintf(resultstring, resultstring_length, "Error in given IPv4 address, '%s' is not valid (illegal char at %d)!",
+			 addrstring, (int)(p - addrstring));
+		return (1);
+	}
+	if (i >= (in_prefix_len ? 5 : 4)) {
+		snprintf(resultstring, resultstring_length, "Error in given IPv4 address, '%s' is not valid (more than 3 dots)!", addrstring);
+		return (1);
+	}
+
+	/* do not allow '1.2', but allow '1.2/12' */
+	if (!in_prefix_len && i < 3) {
+		snprintf(resultstring, resultstring_length, "Error in given IPv4 address, '%s' is not valid (missing %d dots)!", addrstring, 3-i);
+		return (1);
+	}
+	if (!in_prefix_len && p[-1] == '.') {
+		snprintf(resultstring, resultstring_length, "Error in given IPv4 address, '%s' is not valid (missing last octet)!", addrstring);
+		return (1);
+	}
+
+END_addr_to_ipv4addrstruct:
 	ipv4addr_clearall(ipv4addrp);
 
-	/* save prefix length first, if available */
-	addronlystring = strtok_r(tempstring, "/", ptrptr);
-
-	if ( addronlystring == NULL ) {
-		fprintf(stderr, "Strange input (extracting prefix length): %s\n", addrstring);
-		return (1);
-	};
-
-	cp = strtok_r(NULL, "/", ptrptr);
-	if ( cp != NULL ) {
-		i = atoi(cp);
-		if (i < 0 || i > 32 ) {
-			snprintf(resultstring, resultstring_length, "Illegal prefix length: '%s'", cp);
-			retval = 1;
-			return (retval);
-		};
+	if (in_prefix_len) {
 		ipv4addrp->flag_prefixuse = 1;
-		ipv4addrp->prefixlength = (uint8_t) i;
-		
+
+		if (compat[4] > 32) {
+			snprintf(resultstring, resultstring_length, "Error in given IPv4 address, '%s' is not valid (prefix length is out-of-range 0..32)!", addrstring);
+			return (1);
+		};
+		ipv4addrp->prefixlength = (uint8_t) compat[4];
+
 		DEBUGPRINT_WA(DEBUG_libipv4addr, "prefix length %u", (unsigned int) ipv4addrp->prefixlength);
 		DEBUGPRINT_WA(DEBUG_libipv4addr, "flag_prefixuse %d", ipv4addrp->flag_prefixuse);
-	};
+	}
 
-	/* count "." and digits */
-	for (i = 0; i < (int) strlen(addronlystring); i++) {
-		if (addronlystring[i] == '.') {
-			cpoints++;
-		};
-		if (isdigit(addronlystring[i])) {
-			cdigits++;
-		};
-	};
-
-	/* check amount of ".", must be 3 */
-	if ( cpoints != 3 ) {
-		snprintf(resultstring, resultstring_length, "Error in given IPv4 address, '%s' is not valid (only %d dots)!", addronlystring, cpoints);
-		retval = 1;
-		return (retval);
-	};
-
-	/* amount of "." and digits must be length */
-	if (cdigits + cpoints != strlen(addronlystring)) {
-		snprintf(resultstring, resultstring_length, "Error in given IPv4 address, '%s' is not valid (illegal chars)!", addronlystring);
-		retval = 1;
-		return (retval);
-	};
-
-	/* clear variables */
-	for ( i = 0; i <= 3; i++ ) {
-		compat[i] = 0;
-	};
-
-	expecteditems = 4;
-	result = sscanf(addronlystring, "%d.%d.%d.%d", &compat[0], &compat[1], &compat[2], &compat[3]);
-	
-	for ( i = 0; i <= 3; i++ ) {
-		if ( ( compat[i] < 0 ) || ( compat[i] > 255 ) )	{
-			snprintf(resultstring, resultstring_length, "Error in given IPv4 address, '%s' is not valid (%d on position %d)!", addronlystring, compat[i], i+1);
-			retval = 1;
-			return (retval);
-		};
-	};
-	
-	DEBUGPRINT_WA(DEBUG_libipv4addr, "reading into array, got items: %d", result);
-
-	if ( result != expecteditems ) {
-		snprintf(resultstring, resultstring_length, "Error in given IPv4 address, splitting of %s returns %d items instead of %d!", addronlystring, result, expecteditems);
-		retval = 1;
-		return (retval);
-	};
-
-	/* copy into structure */
 	for ( i = 0; i <= 3; i++ ) {
 		DEBUGPRINT_WA(DEBUG_libipv4addr, "Octett %d = %d", i, compat[i]);
-		ipv4addr_setoctet(ipv4addrp, (unsigned int) i, (unsigned int) compat[i]);
+
+		if (compat[i] > 255) {
+			snprintf(resultstring, resultstring_length, "Error in given IPv4 address, '%s' is not valid (decimal value %d on position %d)!", addrstring, compat[i], i+1);
+			return (1);
+		};
+
+		ipv4addr_setoctet(ipv4addrp, i, compat[i]);
 	};
 
 	DEBUGPRINT_WA(DEBUG_libipv4addr, "In structure %03u %03u %03u %03u", (unsigned int) ipv4addr_getoctet(ipv4addrp, 0), (unsigned int) ipv4addr_getoctet(ipv4addrp, 1), (unsigned int) ipv4addr_getoctet(ipv4addrp, 2), (unsigned int) ipv4addr_getoctet(ipv4addrp, 3));
 	DEBUGPRINT_WA(DEBUG_libipv4addr, "In structure %8x", (unsigned int) ipv4addr_getdword(ipv4addrp));
-	
+
 	typeinfo = ipv4addr_gettype(ipv4addrp); 
 
 	DEBUGPRINT_WA(DEBUG_libipv4addr, "Got typeinfo: 0x%08x", typeinfo);
@@ -553,8 +596,7 @@ int addr_to_ipv4addrstruct(const char *addrstring, char *resultstring, const siz
 	ipv4addrp->typeinfo = typeinfo;
 	ipv4addrp->flag_valid = 1;
 
-	retval = 0;
-	return (retval);
+	return (0);
 };
 
 
@@ -571,7 +613,7 @@ int addrhex_to_ipv4addrstruct(const char *addrstring, char *resultstring, const
 	char *addronlystring, *cp;
 	int expecteditems = 0;
 	int compat[4];
-	char tempstring[NI_MAXHOST], *cptr, **ptrptr;
+	char tempstring[IPV6CALC_STRING_MAX], *cptr, **ptrptr;
 	uint32_t typeinfo;
 
 	ptrptr = &cptr;
@@ -638,7 +680,7 @@ int addrhex_to_ipv4addrstruct(const char *addrstring, char *resultstring, const
 	
 	for ( i = 0; i <= 3; i++ ) {
 		if ( ( compat[i] < 0 ) || ( compat[i] > 255 ) )	{
-			snprintf(resultstring, resultstring_length, "Error in given hex notated IPv4 address, '%s' is not valid (%d on position %d)!", addronlystring, compat[i], i+1);
+			snprintf(resultstring, resultstring_length, "Error in given hex notated IPv4 address, '%s' is not valid (decimal value %d on position %d)!", addronlystring, compat[i], i+1);
 			retval = 1;
 			return (retval);
 		};
@@ -681,27 +723,75 @@ int addrhex_to_ipv4addrstruct(const char *addrstring, char *resultstring, const
  * ret: ==0: ok, !=0: error
  */
 int libipv4addr_ipv4addrstruct_to_string(const ipv6calc_ipv4addr *ipv4addrp, char *resultstring, const size_t resultstring_length, const uint32_t formatoptions) {
-	char tempstring[NI_MAXHOST];
-
-	/* address */
-	snprintf(tempstring, sizeof(tempstring), "%u.%u.%u.%u", (unsigned int) ipv4addr_getoctet(ipv4addrp, 0), (unsigned int) ipv4addr_getoctet(ipv4addrp, 1), (unsigned int) ipv4addr_getoctet(ipv4addrp, 2), (unsigned int) ipv4addr_getoctet(ipv4addrp, 3));
+	char tempstring[IPV6CALC_STRING_MAX];
 
 	if ((formatoptions & FORMATOPTION_machinereadable) != 0) {
-		snprintf(resultstring, resultstring_length, "IPV4=%s", tempstring);
+		snprintf(resultstring, resultstring_length, "IPV4=%u.%u.%u.%u",
+			(unsigned int) ipv4addr_getoctet(ipv4addrp, 0),
+			(unsigned int) ipv4addr_getoctet(ipv4addrp, 1),
+			(unsigned int) ipv4addr_getoctet(ipv4addrp, 2),
+			(unsigned int) ipv4addr_getoctet(ipv4addrp, 3));
+	} else if ((formatoptions & FORMATOPTION_print_octal) != 0) {
+		snprintf(tempstring, sizeof(tempstring), "0%03o.0%03o.0%03o.0%03o",
+			(unsigned int) ipv4addr_getoctet(ipv4addrp, 0),
+			(unsigned int) ipv4addr_getoctet(ipv4addrp, 1),
+			(unsigned int) ipv4addr_getoctet(ipv4addrp, 2),
+			(unsigned int) ipv4addr_getoctet(ipv4addrp, 3));
+
+		if ((ipv4addrp->flag_prefixuse == 1) && ((formatoptions & FORMATOPTION_no_prefixlength) == 0)) {
+			snprintf(resultstring, resultstring_length, "%s/%d", tempstring, ipv4addrp->prefixlength);
+		} else {
+			snprintf(resultstring, resultstring_length, "%s", tempstring);
+		};
 	} else {
-		if (ipv4addrp->flag_prefixuse == 1) {
+		int oct_to_print = 4;
+
+		if ((formatoptions & FORMATOPTION_printcompressed) != 0) {
+			for (; oct_to_print > 1; oct_to_print--)
+				if (ipv4addr_getoctet(ipv4addrp, oct_to_print-1) != 0)
+					break;
+		}
+
+		switch (oct_to_print) {
+		case 4:
+			snprintf(tempstring, sizeof(tempstring), "%u.%u.%u.%u",
+			         (unsigned int) ipv4addr_getoctet(ipv4addrp, 0),
+			         (unsigned int) ipv4addr_getoctet(ipv4addrp, 1),
+			         (unsigned int) ipv4addr_getoctet(ipv4addrp, 2),
+			         (unsigned int) ipv4addr_getoctet(ipv4addrp, 3));
+			break;
+
+		case 3:
+			snprintf(tempstring, sizeof(tempstring), "%u.%u.%u",
+			         (unsigned int) ipv4addr_getoctet(ipv4addrp, 0),
+			         (unsigned int) ipv4addr_getoctet(ipv4addrp, 1),
+			         (unsigned int) ipv4addr_getoctet(ipv4addrp, 2));
+			break;
+
+		case 2:
+			snprintf(tempstring, sizeof(tempstring), "%u.%u",
+			         (unsigned int) ipv4addr_getoctet(ipv4addrp, 0),
+			         (unsigned int) ipv4addr_getoctet(ipv4addrp, 1));
+			break;
+
+		case 1:
+			snprintf(tempstring, sizeof(tempstring), "%u",
+			         (unsigned int) ipv4addr_getoctet(ipv4addrp, 0));
+			break;
+
+		default:
+			/* should not happen here */
+			fprintf(stderr, "%s/%s: 'oct_to_print' has an unexpected illegal value!\n", __FILE__, __func__);
+			exit(EXIT_FAILURE);
+		}
+
+		if ((ipv4addrp->flag_prefixuse == 1) && ((formatoptions & FORMATOPTION_no_prefixlength) == 0)) {
 			snprintf(resultstring, resultstring_length, "%s/%d", tempstring, ipv4addrp->prefixlength);
 		} else {
 			snprintf(resultstring, resultstring_length, "%s", tempstring);
 		};
 	};
 
-	/* netmask/prefixlength */
-	if (ipv4addrp->flag_prefixuse == 1) {
-		/* to be filled */
-		/* IPV4NETMASK= */
-	};
-	
 	return(0);
 };
 
@@ -717,7 +807,7 @@ int libipv4addr_to_reversestring(const ipv6calc_ipv4addr *ipv4addrp, char *resul
 	int retval = 1;
 	uint8_t octet;
 	int bit_start, bit_end, nbit;
-	char tempstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
 	unsigned int noctet;
 	
 	if ( ((formatoptions & (FORMATOPTION_printprefix | FORMATOPTION_printsuffix | FORMATOPTION_printstart | FORMATOPTION_printend)) == 0 ) && ((*ipv4addrp).flag_prefixuse != 0) ) {
@@ -772,13 +862,13 @@ int libipv4addr_to_reversestring(const ipv6calc_ipv4addr *ipv4addrp, char *resul
  * function prints an IPv4 address in native octal format
  *
  * in:  ipv4addr = IPv4 address structure
- * formatoptions
+ * in:  formatoptions
  * out: *resultstring = IPv4 address (modified)
  * ret: ==0: ok, !=0: error
  */
 int libipv4addr_to_octal(const ipv6calc_ipv4addr *ipv4addrp, char *resultstring, const size_t resultstring_length, const uint32_t formatoptions) {
 	int retval = 1;
-	char tempstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
 
 	if ( (formatoptions & FORMATOPTION_printfulluncompressed) != 0 ) {
 		snprintf(tempstring, sizeof(tempstring), "\\0%03o\\0%03o\\0%03o\\0%03o",
@@ -802,6 +892,83 @@ int libipv4addr_to_octal(const ipv6calc_ipv4addr *ipv4addrp, char *resultstring,
 };
 
 
+/*
+ * mask prefix bits (set suffix bits to 0)
+ *
+ * in:  structure via reference
+ * out: modified structure
+ */
+void ipv4addrstruct_maskprefix(ipv6calc_ipv4addr *ipv4addrp) {
+	unsigned int nbit, nword;
+	uint16_t mask, newword;
+	int i;
+
+	DEBUGPRINT_NA(DEBUG_libipv4addr, "called");
+
+	if (ipv4addrp->flag_prefixuse != 1) {
+		/* hmm, no prefix specified. skip */
+		return;
+	};
+
+	for (i = 31; i >= 0; i--) {
+		nbit = (unsigned int) i;
+		if (nbit >= (unsigned int) ipv4addrp->prefixlength) {
+			/* set bit to zero */
+
+			/* calculate word (16 bit) - matches with addr4p[]*/
+			nword = (nbit & 0x70) >> 4;
+
+			/* calculate mask */
+			mask = ((uint16_t) 0x8000u) >> (( ((uint16_t) nbit) & ((uint16_t) 0x0fu)));
+			newword = ipv4addr_getword(ipv4addrp, nword) & (~ mask );
+
+			DEBUGPRINT_WA(DEBUG_libipv4addr, "bit: %u = nword: %u, mask: %04x, word: %04x newword: %04x", nbit, nword, (unsigned int) mask, (unsigned int) ipv4addr_getword(ipv4addrp, nword), (unsigned int) newword);
+
+			ipv4addr_setword(ipv4addrp, nword, (unsigned int) newword);
+		};
+	};
+};
+
+
+/*
+ * mask suffix bits (set prefix bits to 0)
+ *
+ * in:  structure via reference
+ * out: modified structure
+ */
+void ipv4addrstruct_masksuffix(ipv6calc_ipv4addr *ipv4addrp) {
+	unsigned int nbit, nword;
+	uint16_t mask, newword;
+	int i;
+
+	DEBUGPRINT_NA(DEBUG_libipv4addr, "called");
+ 
+	if (ipv4addrp->flag_prefixuse != 1) {
+		/* hmm, no prefix specified. skip */
+		return;
+	};
+
+	for (i = 31; i >= 0; i--) {
+		nbit = (unsigned int) i;
+
+		if (nbit < (unsigned int) ipv4addrp->prefixlength) {
+			/* set bit to zero */
+
+			/* calculate word (16 bit) - matches with addr4p[]*/
+			nword = (nbit & 0x70) >> 4;
+
+			/* calculate mask */
+			mask = ((uint32_t) 0x8000u) >> (((uint32_t) nbit) & ((uint32_t) 0x0fu ));
+			newword = ipv4addr_getword(ipv4addrp, nword) & (~ mask );
+
+			DEBUGPRINT_WA(DEBUG_libipv4addr, "%u = nword: %u, mask: %04x, word: %04x newword: %04x", nbit, nword, (unsigned int) mask, (unsigned int) ipv4addr_getword(ipv4addrp, nword), (unsigned int) newword);
+
+			ipv4addr_setword(ipv4addrp, nword, (unsigned int) newword);
+		};
+	};
+};
+
+
 /*
  * function prints an IPv4 address in native hex format
  *
@@ -816,7 +983,7 @@ int libipv4addr_to_hex(const ipv6calc_ipv4addr *ipv4addrp, char *resultstring, c
 	int retval = 1;
 	int i;
 	unsigned int s;
-	char tempstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
 
 	snprintf(tempstring, sizeof(tempstring), "%02x%02x%02x%02x",
 		(unsigned int) ipv4addr_getoctet(ipv4addrp, 0),  \
@@ -1113,9 +1280,9 @@ int ipv4addr_filter_parse(s_ipv6calc_filter_ipv4addr *filter, const char *token)
 	const char *prefixaddreq_ge2 = "addr=ge=";
 	const char *prefixaddreq_gt2 = "addr=gt=";
 	ipv6calc_ipv4addr ipv4addr;
-	char resultstring[NI_MAXHOST];
-	int db = 0, addr = 0;
-	int addr_test_method;
+	char resultstring[IPV6CALC_STRING_MAX];
+	int db = 0;
+	int addr_test_method = IPV6CALC_TEST_NONE;
 
 	if (token == NULL) {
 		return (result);
@@ -1154,63 +1321,54 @@ int ipv4addr_filter_parse(s_ipv6calc_filter_ipv4addr *filter, const char *token)
 	if (strncmp(token + offset, prefixaddreq_le, strlen(prefixaddreq_le)) == 0) {
 		/* prefixaddr with = found */
 		DEBUGPRINT_WA(DEBUG_libipv4addr, "found 'addr<=' prefix in token: %s", token);
-		addr = 1;
 		offset += strlen(prefixaddreq_le);
 		addr_test_method = IPV6CALC_TEST_LE;
 
 	} else if (strncmp(token + offset, prefixaddreq_lt, strlen(prefixaddreq_lt)) == 0) {
 		/* prefixaddr with = found */
 		DEBUGPRINT_WA(DEBUG_libipv4addr, "found 'addr<' prefix in token: %s", token);
-		addr = 1;
 		offset += strlen(prefixaddreq_lt);
 		addr_test_method = IPV6CALC_TEST_LT;
 
 	} else if (strncmp(token + offset, prefixaddreq_ge, strlen(prefixaddreq_ge)) == 0) {
 		/* prefixaddr with = found */
 		DEBUGPRINT_WA(DEBUG_libipv4addr, "found 'addr>=' prefix in token: %s", token);
-		addr = 1;
 		offset += strlen(prefixaddreq_ge);
 		addr_test_method = IPV6CALC_TEST_GE;
 
 	} else if (strncmp(token + offset, prefixaddreq_gt, strlen(prefixaddreq_gt)) == 0) {
 		/* prefixaddr with = found */
 		DEBUGPRINT_WA(DEBUG_libipv4addr, "found 'addr>' prefix in token: %s", token);
-		addr = 1;
 		offset += strlen(prefixaddreq_gt);
 		addr_test_method = IPV6CALC_TEST_GT;
 
 	} else if (strncmp(token + offset, prefixaddreq_le2, strlen(prefixaddreq_le2)) == 0) {
 		/* prefixaddr with = found */
 		DEBUGPRINT_WA(DEBUG_libipv4addr, "found 'addr=le=' prefix in token: %s", token);
-		addr = 1;
 		offset += strlen(prefixaddreq_le2);
 		addr_test_method = IPV6CALC_TEST_LE;
 
 	} else if (strncmp(token + offset, prefixaddreq_lt2, strlen(prefixaddreq_lt2)) == 0) {
 		/* prefixaddr with = found */
 		DEBUGPRINT_WA(DEBUG_libipv4addr, "found 'addr=lt=' prefix in token: %s", token);
-		addr = 1;
 		offset += strlen(prefixaddreq_lt2);
 		addr_test_method = IPV6CALC_TEST_LT;
 
 	} else if (strncmp(token + offset, prefixaddreq_ge2, strlen(prefixaddreq_ge2)) == 0) {
 		/* prefixaddr with = found */
 		DEBUGPRINT_WA(DEBUG_libipv4addr, "found 'addr=ge=' prefix in token: %s", token);
-		addr = 1;
 		offset += strlen(prefixaddreq_ge2);
 		addr_test_method = IPV6CALC_TEST_GE;
 
 	} else if (strncmp(token + offset, prefixaddreq_gt2, strlen(prefixaddreq_gt2)) == 0) {
 		/* prefixaddr with = found */
 		DEBUGPRINT_WA(DEBUG_libipv4addr, "found 'addr=gt=' prefix in token: %s", token);
-		addr = 1;
 		offset += strlen(prefixaddreq_gt2);
 		addr_test_method = IPV6CALC_TEST_GT;
 
 	} else if (strncmp(token + offset, prefixaddreq, strlen(prefixaddreq)) == 0) {
 		/* prefixaddr with = found */
 		DEBUGPRINT_WA(DEBUG_libipv4addr, "found 'addr=' prefix in token: %s", token);
-		addr = 1;
 		offset += strlen(prefixaddreq);
 		addr_test_method = IPV6CALC_TEST_PREFIX;
 
@@ -1226,7 +1384,7 @@ int ipv4addr_filter_parse(s_ipv6calc_filter_ipv4addr *filter, const char *token)
 	};
 
 
-	if ((db == 0) && (addr == 0)) {
+	if ((db == 0) && (addr_test_method == IPV6CALC_TEST_NONE)) {
 		// typeinfo token
 		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv4addrtypestrings); i++ ) {
 			DEBUGPRINT_WA(DEBUG_libipv4addr, "check token against: %s", ipv6calc_ipv4addrtypestrings[i].token);
@@ -1270,7 +1428,7 @@ int ipv4addr_filter_parse(s_ipv6calc_filter_ipv4addr *filter, const char *token)
 		};
 	};
 
-	if (addr == 1) {
+	if (addr_test_method != IPV6CALC_TEST_NONE) {
 		DEBUGPRINT_WA(DEBUG_libipv4addr, "try to parse IPv4 address: %s", token + offset);
 
 		r = addr_to_ipv4addrstruct(token + offset, resultstring, sizeof(resultstring), &ipv4addr);
@@ -1323,7 +1481,7 @@ END_ipv4addr_filter_parse:
  */
 int ipv4addr_filter_check(const s_ipv6calc_filter_ipv4addr *filter) {
 	int result = 0, r, i;
-	char resultstring[NI_MAXHOST];
+	char resultstring[IPV6CALC_STRING_MAX];
 
 	DEBUGPRINT_WA(DEBUG_libipv4addr, "ipv4 filter general active         : %d", filter->active);
 
@@ -1551,6 +1709,8 @@ uint32_t libipv4addr_as_num32_by_addr(const ipv6calc_ipv4addr *ipv4addrp, unsign
 	uint32_t as_num32 = ASNUM_AS_UNKNOWN;
 	ipv6calc_ipaddr ipaddr;
 
+	DEBUGPRINT_WA(DEBUG_libipv4addr, "typeinfo=%08x", ipv4addrp->typeinfo);
+
 	if ((ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED) != 0) {
 		as_num32 = ipv4addr_anonymized_get_as_num32(ipv4addrp);
 	} else {
@@ -1572,7 +1732,7 @@ uint32_t libipv4addr_as_num32_by_addr(const ipv6calc_ipv4addr *ipv4addrp, unsign
  * out: registry number
  */
 int libipv4addr_registry_num_by_addr(const ipv6calc_ipv4addr *ipv4addrp) {
-	int registry = IPV4_ADDR_REGISTRY_UNKNOWN;
+	int registry = REGISTRY_UNKNOWN;
 	uint32_t as_num32;
 	uint16_t cc_index;
 
@@ -1594,7 +1754,7 @@ int libipv4addr_registry_num_by_addr(const ipv6calc_ipv4addr *ipv4addrp) {
 			if (as_num32 != ASNUM_AS_UNKNOWN) {
 				registry = libipv6calc_db_wrapper_registry_num_by_as_num32(as_num32);
 			};
-			if ((as_num32 == ASNUM_AS_UNKNOWN) || (registry == IPV4_ADDR_REGISTRY_ARIN)) {
+			if ((as_num32 == ASNUM_AS_UNKNOWN) || (registry == REGISTRY_ARIN)) {
 				/* retrieve registry via cc_index from anonymized address (simple, fallback) */
 				cc_index = libipv4addr_cc_index_by_addr(ipv4addrp, NULL);
 				registry = libipv6calc_db_wrapper_registry_num_by_cc_index(cc_index);
@@ -1659,3 +1819,17 @@ uint32_t libipv4addr_GeonameID_by_addr(const ipv6calc_ipv4addr *ipv4addrp, unsig
 
 	return(GeonameID);
 };
+
+
+/* cleanup */
+void libipv4addr_cleanup() {
+	DEBUGPRINT_NA(DEBUG_libipv4addr, "called");
+	int i;
+
+	for (i = 0; i < LIBIPV4ADDR_REGEX_CACHE_MAX; i++) {
+		if (libipv4addr_regex_cache_valid[i]) {
+			DEBUGPRINT_WA(DEBUG_libipv4addr, "free regex cache entry: %d", i);
+			regfree(&libipv4addr_regex_cache_entry[i]);
+		};
+	};
+};
