@@ -1,24 +1,29 @@
 /*
  * Project    : ipv6calc
  * File       : libipv6addr.h
- * Version    : $Id: a7b412b2d106955ba6b682c2e8be15d13b3d1ffc $
- * Copyright  : 2001-2019 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
+ * Version    : $Id: dc01157e5ec8acc3a0b5d0a0a13a07b995dfc602 $
+ * Copyright  : 2001-2021 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  * License    : GNU GPL v2
  *
  * Information:
  *  Header file for libipv6addr.c
  */ 
 
-#include "ipv6calctypes.h"
-#include <netinet/in.h>
-#include <ctype.h>
-
-/* typedefs & defines */
-
 #ifndef _libipv6addr_h
 
 #define _libipv6addr_h 1
 
+
+#include <netinet/in.h>
+#include <ctype.h>
+#include "ipv6calctypes.h"
+#include "libipv4addr.h"
+//#include "ipv6calc_typedefs.h"
+
+
+/* typedefs & defines */
+
+
 /* IPv6 anonymization */
 /* 
  * IID anonymization is done by replacing with related information (64-bit)
@@ -27,9 +32,9 @@
  * a9p9 4941 0000 000C  -> RFC 4941 anonymized privacy extension Interface ID
  *
  * a9p9 4291 4xxx xxxC  -> RFC 4291 anonymized EUI-48 Interface ID, xxx xxx = converted OUI
- * a9p9 4291 5xxx xxxC  -> RFC 4291 anonymized EUI-48 Interface ID, xxx xxx = converted mapped IAB/OUI-36
+ * a9p9 4291 5xxx xxxC  -> RFC 4291 anonymized EUI-48 Interface ID, xxx xxx = converted mapped IAB/OUI-36/OUI-28
  * a9p9 4291 6xxx xxxC  -> RFC 4291 anonymized EUI-64 Interface ID, xxx xxx = converted OUI
- * a9p9 4291 7xxx xxxC  -> RFC 4291 anonymized EUI-64 Interface ID, xxx xxx = converted mapped IAB/OUI-36
+ * a9p9 4291 7xxx xxxC  -> RFC 4291 anonymized EUI-64 Interface ID, xxx xxx = converted mapped IAB/OUI-36/OUI-28
  * a9p9 4291 8xxx xxxC  -> RFC 4291 embedded anonymized IPv4 address, xxx xxx = first 24 bit of included (anonymized) IPv4 address
  * a9p9 4291 c02d 5d1C  -> RFC 4291 Chapter 2.5.1 anonymized static Interface ID
  *
@@ -223,15 +228,17 @@ typedef struct {
 	uint8_t  test_mode;		/* address test mode */
 } ipv6calc_ipv6addr;
 
+
 /* IPv6 Address filter structure */
 typedef struct {
         int active;
         int addr_must_have_max;
         int addr_may_not_have_max;
-        ipv6calc_ipv6addr ipv6addr_must_have[IPV6CALC_FILTER_IPV4ADDR];
+        ipv6calc_ipv6addr ipv6addr_must_have[IPV6CALC_FILTER_IPV6ADDR];
         ipv6calc_ipv6addr ipv6addr_may_not_have[IPV6CALC_FILTER_IPV6ADDR];
 } s_ipv6calc_filter_addr_ipv6;
 
+
 /* IPv6 filter structure */
 typedef struct {
 	int active;
@@ -256,29 +263,6 @@ typedef struct {
 	int   digit_delta_amount;  	// amount of delta of digits
 } s_iid_statistics;
 
-/* IID random limits */
-// this filter values detects 999.744 from 1.000.000 generated random (using privacy extension) IIDs (256 are not detected)
-/*@unused@*/ static const s_iid_statistics s_iid_statistics_ok_min = {
-	0.249,		// fits to 100% of 1 million tested
-	6.275,		// fits to 100% of 1 million tested
-	{  4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},	// fit to 100% of 1 million tested
-	{  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},	// fit to 100% of 1 million tested
-	{  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},	// default
-	{  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, // default
-	6	// fit to 1 million
-};
-
-/*@unused@*/ static const s_iid_statistics s_iid_statistics_ok_max = {
-	2.5,		// fits to 1 million - 90 tested (100%: 4.016)
-	26.042,		// fits to 100% of 1 million tested
-	{ 16, 6, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},	// fit to 1 million - 3 tested
-	{  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2},	// TODO
-	{  7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7},	// fit to 1 million - 38 tested
-	{  3, 4, 3, 3, 4, 5, 4, 5, 5, 5, 6, 6, 6, 7, 7, 6, 6, 7, 6, 6, 6, 5, 5, 5, 4, 4, 4, 4, 4, 3, 2},	// fit to 1 million
-	15	// fit to 1 million
-};
-
-
 
 /* IPv6 address type definitions 
  * with credits to kernel and USAGI developer team
@@ -359,80 +343,20 @@ typedef struct {
 #define IPV6_ADDR_SELECT_IPV4_TEREDO_SERVER	1
 #define IPV6_ADDR_SELECT_IPV4_PREFIX2_LENGTH	2
 
-/* text representations */
-/*@unused@*/ static const s_type ipv6calc_ipv6addrtypestrings[] = {
-	{ IPV6_ADDR_ANY			, "unknown" },
-	{ IPV6_ADDR_UNICAST		, "unicast" },
-	{ IPV6_ADDR_MULTICAST		, "multicast" },
-	{ IPV6_ADDR_ANYCAST		, "anycast" },
-	{ IPV6_ADDR_LOOPBACK		, "loopback" },
-	{ IPV6_ADDR_LINKLOCAL		, "link-local" },
-	{ IPV6_ADDR_SITELOCAL		, "site-local" },
-	{ IPV6_ADDR_COMPATv4		, "compat-v4" },
-	{ IPV6_ADDR_MAPPED		, "mapped" },
-	{ IPV6_ADDR_RESERVED		, "reserved" },
-	{ IPV6_ADDR_ULUA		, "unique-local-unicast" },
-	{ IPV6_ADDR_ANONYMIZED_IID	, "anonymized-iid" },
-	{ IPV6_ADDR_ANONYMIZED_PREFIX	, "anonymized-prefix" },
-	{ IPV6_NEW_ADDR_6TO4		, "6to4" },
-	{ IPV6_NEW_ADDR_6BONE		, "6bone" },
-	{ IPV6_NEW_ADDR_AGU		, "global-unicast" },
-	{ IPV6_NEW_ADDR_UNSPECIFIED	, "unspecified" },
-	{ IPV6_NEW_ADDR_SOLICITED_NODE	, "solicited-node" },
-	{ IPV6_NEW_ADDR_PRODUCTIVE	, "productive" },
-	{ IPV6_NEW_ADDR_6TO4_MICROSOFT	, "6to4-microsoft" },
-	{ IPV6_NEW_ADDR_TEREDO		, "teredo" },
-	{ IPV6_NEW_ADDR_ORCHID		, "orchid" },
-	{ IPV6_NEW_ADDR_LINKLOCAL_TEREDO, "link-local-teredo" },
-	{ IPV6_NEW_ADDR_NAT64		, "nat64" },
-	{ IPV6_NEW_ADDR_IID_RANDOM	, "iid-random" },
-	{ IPV6_NEW_ADDR_IID		, "iid" },
-	{ IPV6_NEW_ADDR_IID_LOCAL	, "iid-local" },
-	{ IPV6_NEW_ADDR_IID_GLOBAL	, "iid-global" },
-	{ IPV6_NEW_ADDR_IID_TEREDO	, "iid-teredo" },
-	{ IPV6_NEW_ADDR_IID_EUI48	, "iid-eui48" },
-	{ IPV6_NEW_ADDR_IID_EUI64	, "iid-eui64" },
-	{ IPV6_NEW_ADDR_IID_ISATAP	, "iid-isatap" },
-	{ IPV6_ADDR_IID_32_63_HAS_IPV4	, "iid-includes-ipv4" }
-};
+/* text representations -> libipv6addr.c */
 
-/* text representations */
-/*@unused@*/ static const s_type ipv6calc_ipv6addr_type2_strings[] = {
-	{ IPV6_ADDR_TYPE2_6RD		, "6rd" },
-	{ IPV6_ADDR_TYPE2_LISP	 		, "lisp" },
-	{ IPV6_ADDR_TYPE2_LISP_PETR		, "lisp-proxyegresstunnelrouter-anycast" },
-	{ IPV6_ADDR_TYPE2_LISP_MAP_RESOLVER	, "lisp-mapresolver-anycast" },
-	{ IPV6_ADDR_TYPE2_ANON_MASKED_PREFIX    , "anonymized-masked-prefix" },
-	{ IPV6_ADDR_TYPE2_ANONYMIZED_GEONAMEID  , "anonymized-geonameid" },
-};
 
-/* Registries */
-#include "libipv6calc.h"
-
-#define IPV6_ADDR_REGISTRY_6BONE	REGISTRY_6BONE
-#define IPV6_ADDR_REGISTRY_IANA		REGISTRY_IANA
-#define IPV6_ADDR_REGISTRY_APNIC	REGISTRY_APNIC
-#define IPV6_ADDR_REGISTRY_ARIN		REGISTRY_ARIN
-#define IPV6_ADDR_REGISTRY_RIPENCC	REGISTRY_RIPENCC
-#define IPV6_ADDR_REGISTRY_LACNIC	REGISTRY_LACNIC
-#define IPV6_ADDR_REGISTRY_AFRINIC	REGISTRY_AFRINIC
-#define IPV6_ADDR_REGISTRY_RESERVED	REGISTRY_RESERVED
-#define IPV6_ADDR_REGISTRY_UNKNOWN	REGISTRY_UNKNOWN
-
-/*@unused@*/ static const s_type2 ipv6calc_ipv6addrregistry[] = {
-	{ IPV6_ADDR_REGISTRY_6BONE	, "6BONE"	, "6BONE" 	},
-	{ IPV6_ADDR_REGISTRY_IANA	, "IANA"	, "IANA" 	},
-	{ IPV6_ADDR_REGISTRY_APNIC	, "APNIC"	, "APNIC" 	},
-	{ IPV6_ADDR_REGISTRY_ARIN	, "ARIN" 	, "ARIN"	},
-	{ IPV6_ADDR_REGISTRY_RIPENCC	, "RIPE NCC"	, "RIPENCC"	},
-	{ IPV6_ADDR_REGISTRY_LACNIC	, "LACNIC"	, "LACNIC"	},
-	{ IPV6_ADDR_REGISTRY_AFRINIC	, "AFRINIC"	, "AFRINIC"	},
-	{ IPV6_ADDR_REGISTRY_RESERVED	, "reserved"	, "reserved"	},
-	{ IPV6_ADDR_REGISTRY_UNKNOWN	, "unknown"	, "unknown"	}
-};
 #endif
 
 
+/* references */
+extern const s_type ipv6calc_ipv6addrtypestrings[];
+extern const int    ipv6calc_ipv6addrtypestrings_entries;
+
+extern const s_type ipv6calc_ipv6addr_type2_strings[];
+extern const int    ipv6calc_ipv6addr_type2_strings_entries;
+
+
 /* prototypes */
 extern uint8_t  ipv6addr_getoctet(const ipv6calc_ipv6addr *ipv6addrp, const unsigned int numoctet);
 extern uint16_t ipv6addr_getword(const ipv6calc_ipv6addr *ipv6addrp, const unsigned int numword);
