@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv6calcdebug.h
- * Version    : $Id: 2d0a952bb1dcfa81ca53caaa0f67868e4dceb88f $
- * Copyright  : 2002-2013 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 4c54d967102db09a097060935324ecc97cffa5af $
+ * Copyright  : 2002-2019 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Debug information
@@ -41,6 +41,7 @@
 
 #define DEBUG_libipv6calc_db_wrapper			0x00100000l
 #define DEBUG_libipv6calc_db_wrapper_GeoIP		0x00200000l
+#define DEBUG_libipv6calc_db_wrapper_GeoIP2		0x00200000l
 #define DEBUG_libipv6calc_db_wrapper_IP2Location	0x00400000l
 #define DEBUG_libipv6calc_db_wrapper_GeoIP_verbose	0x00800000l
 
@@ -48,8 +49,10 @@
 #define DEBUG_libipv6addr_anonymization_unknown_break	0x02000000l
 
 #define DEBUG_libipv6calc_db_wrapper_DBIP		0x10000000l
+#define DEBUG_libipv6calc_db_wrapper_DBIP2		0x10000000l
 #define DEBUG_libipv6calc_db_wrapper_External		0x20000000l
 #define DEBUG_libipv6calc_db_wrapper_BuiltIn		0x40000000l
+#define DEBUG_libipv6calc_db_wrapper_MMDB		0x80000000l
 
 /* debug print with args */
 #define DEBUGPRINT_WA(d, t, ...)	\
