@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : libmac.c
- * Version    : $Id: 135622fbbe9ea93e7da6abdecbf555ab9b299679 $
- * Copyright  : 2001-2016 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 1919e345cb70cb21c1e324e12563dec527b03fd2 $
+ * Copyright  : 2001-2019 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Function library MAC address handling
@@ -161,7 +161,7 @@ void mac_clearall(ipv6calc_macaddr *macaddrp) {
  * ret: ==0: ok, !=0: error
  */
 int macaddrstruct_to_string(const ipv6calc_macaddr *macaddrp, char *resultstring, const size_t resultstring_length, const uint32_t formatoptions) {
-	char tempstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
 
 	/* address */
 	snprintf(tempstring, sizeof(tempstring), "%02x:%02x:%02x:%02x:%02x:%02x", (unsigned int) macaddrp->addr[0], (unsigned int) macaddrp->addr[1], (unsigned int) macaddrp->addr[2], (unsigned int) macaddrp->addr[3], (unsigned int) macaddrp->addr[4], (unsigned int) macaddrp->addr[5]);
@@ -236,6 +236,11 @@ void libmacaddr_anonymize(ipv6calc_macaddr *macaddrp, const s_ipv6calc_anon_set
 			if (libieee_check_oui36_iab(EUI48_00_23(macaddrp->addr)) == 1) {
 				// OUI-36/IAB
 				mask += 12; // increase by 12 bits
+				DEBUGPRINT_WA(DEBUG_libmac, "EUI-48 contains OUI-36/IAB, change mask: %d", mask);
+			} else if (libieee_check_oui28(EUI48_00_23(macaddrp->addr)) == 1) {
+				// OUI-28
+				mask += 4; // increase by 4 bits
+				DEBUGPRINT_WA(DEBUG_libmac, "EUI-48 contains OUI-28, change mask: %d", mask);
 			};
 
 			DEBUGPRINT_WA(DEBUG_libmac, "EUI-48 is a global one, source of mask: automagic: %d", mask);
