@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : libmac.h
- * Version    : $Id: c865560bac3eaca479657fc89ac1726299ee1959 $
+ * Version    : $Id: 860f35647868bb753a510b3c596e5bec9943fb84 $
  * Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -9,13 +9,14 @@
  */ 
 
 
-#include "ipv6calc_inttypes.h"
-
-
 #ifndef _libmac_h
 
 #define _libmac_h 1
 
+
+#include "libipv6calc.h"
+
+
 /* typedefs */
 
 typedef struct {
@@ -33,8 +34,10 @@ typedef struct {
 #define EUI48_00_23(x)  ((x[0] << 16) | (x[1] << 8) | x[2])
 #define EUI48_24_47(x)  ((x[3] << 16) | (x[4] << 8) | x[5])
 
+
 #endif
 
+
 /* prototypes */
 extern int mac_to_macaddrstruct(const char *addrstring, char *resultstring, const size_t resultstring_length, ipv6calc_macaddr *macaddrp);
 extern int addr_to_macaddrstruct(const char *addrstring, char *resultstring, const size_t resultstring_length, ipv6calc_macaddr *macaddrp); // compatible name
