@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : librfc1924.c
- * Version    : $Id: 3944d1bf78c2fd522c5056b42a50fa44021319e9 $
+ * Version    : $Id: 59164909b77cf84bff5ada31fbd203724e233af5 $
  * Copyright  : 2001-2019 by Peter Bieringer <pb (at) bieringer.de>
  *              and 2006 by Niko Tyni <ntyni (at) iki.fi>
  *
@@ -142,7 +142,7 @@ int ipv6addrstruct_to_base85(const ipv6calc_ipv6addr *ipv6addrp, char *resultstr
 
 int base85_to_ipv6addrstruct(const char *addrstring, char *resultstring, const size_t resultstring_length, ipv6calc_ipv6addr *ipv6addrp) {
 	int retval = 1, i;
-	char tempstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
 	uint16_t result[8];
 
 	retval = librfc1924_formatcheck(addrstring, resultstring, resultstring_length);
